<?php
/**
 * Widget API: Elementer Portfolio Widget
 * @package karigari
 * @subpackage Widgets
 * @since 1.0.0
 */

namespace Elementor;
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Elementor Portfolio widget.
 * Elementor widget that displays a Portfolio with the ability to control every
 * aspect of the Portfolio design.
 * @since 1.0.0
 */
class Widget_Portfolio extends Widget_Base {
	/**
	 * Get widget name.
	 * Retrieve Portfolio widget name.
	 * @since 1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return esc_html__( 'Portfolio', 'karigari' );
	}

	/**
	 * Get widget title.
	 * Retrieve Portfolio widget title.
	 * @since 1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Portfolio', 'karigari' );
	}

	/**
	 * Get widget icon.
	 * Retrieve Portfolio widget icon.
	 * @since 1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_categories() {
		return array( 'karigari' );
	}

	/**
	 * Get widget icon.
	 * Retrieve heading widget icon.
	 * @since 1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-image';
	}

	/**
	 * Register Portfolio widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @since 1.0.0
	 * @access protected
	 */
	// @codingStandardsIgnoreStart
	protected function register_controls() {

		// @codingStandardsIgnoreEnd
		$this->start_controls_section(
			'portfolio',
			array(
				'label' => esc_html__( 'Portfolio', 'karigari' ),
			)
		);

		$this->add_control(
			'portfolio-style',
			array(
				'label'   => esc_html__( 'Portfolio Style', 'karigari' ),
				'type'    => Controls_Manager::SELECT,
				'options' => array(
					'Portfolio-style-1' => esc_html__( 'Morden Style', 'karigari' ),
					'Portfolio-style-2' => esc_html__( 'Classic Style', 'karigari' ),
				),
				'default' => 'Portfolio-style-1',
			)
		);

		$this->add_control(
			'portfolio-type',
			array(
				'label'   => esc_html__( 'Portfolio Type', 'karigari' ),
				'type'    => Controls_Manager::SELECT,
				'options' => array(
					'slider' => esc_html__( 'Slider', 'karigari' ),
					'grid'   => esc_html__( 'Grid', 'karigari' ),
				),
				'default' => 'slider',
			)
		);


		$this->add_control(
			'display-date',
			array(

				'label'   => esc_html__( 'Post Date', 'karigari' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
				'yes'     => esc_html__( 'yes', 'karigari' ),
				'no'      => esc_html__( 'no', 'karigari' ),
			)
		);

		$this->add_control(
			'post-number',
			array(
				'label'       => esc_html__( 'Products per Page', 'karigari' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'label_block' => true,
				'default'     => '5',
			)
		);

		$this->add_control(
			'post-order',
			array(
				'label'   => esc_html__( 'Post Order', 'karigari' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'ASC',
				'options' => array(
					'DESC' => esc_html__( 'Descending', 'karigari' ),
					'ASC'  => esc_html__( 'Ascending', 'karigari' ),

				),

			)
		);

		$this->add_control(
			'portfolio-col',
			array(
				'label'     => esc_html__( 'Portfolio Slider Style', 'karigari' ),
				'type'      => Controls_Manager::SELECT,
				'condition' => array(
					'portfolio-type' => 'grid',
				),
				'options'   => array(
					'col-md-12'                  => esc_html__( 'Column 1', 'karigari' ),
					'col-md-6'                   => esc_html__( 'Column 2', 'karigari' ),
					'col-xl-4 col-lg-6 col-md-6' => esc_html__( 'Column 3', 'karigari' ),
					'col-lg-3 col-md-6'          => esc_html__( 'Column 4', 'karigari' ),
				),
				'default'   => 'col-xl-4 col-lg-6 col-md-6',
			)
		);

		$this->add_control(
			'desk-number',
			array(
				'label'       => esc_html__( 'Desktop', 'karigari' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'condition'   => array(
					'portfolio-type' => 'slider',
				),
				'label_block' => true,
				'default'     => '3',
			)
		);

		$this->add_control(
			'laptop-number',
			array(
				'label'       => esc_html__( 'Laptop', 'karigari' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'condition'   => array(
					'portfolio-type' => 'slider',
				),
				'label_block' => true,
				'default'     => '3',
			)
		);

		$this->add_control(
			'tablet-number',
			array(
				'label'       => esc_html__( 'Tablet', 'karigari' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'condition'   => array(
					'portfolio-type' => 'slider',
				),
				'label_block' => true,
				'default'     => '3',
			)
		);

		$this->add_control(
			'mobile-number',
			array(
				'label'       => esc_html__( 'Mobile', 'karigari' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'condition'   => array(
					'portfolio-type' => 'slider',
				),
				'label_block' => true,
				'default'     => '2',
			)
		);

		$this->add_control(
			'autoplay',
			array(
				'label'     => esc_html__( 'Autoplay', 'karigari' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'true',
				'condition' => array(
					'portfolio-type' => 'slider',
				),
				'options'   => array(
					'true'  => esc_html__( 'True', 'karigari' ),
					'false' => esc_html__( 'False', 'karigari' ),
				),

			)
		);

		$this->add_control(
			'loop',
			array(
				'label'     => esc_html__( 'Loop', 'karigari' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'false',
				'condition' => array(
					'portfolio-type' => 'slider',
				),
				'options'   => array(
					'true'  => esc_html__( 'True', 'karigari' ),
					'false' => esc_html__( 'False', 'karigari' ),
				),

			)
		);

		$this->add_control(
			'dots',
			array(
				'label'     => esc_html__( 'Dots', 'karigari' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'true',
				'condition' => array(
					'portfolio-type' => 'slider',
				),
				'options'   => array(
					'true'  => esc_html__( 'True', 'karigari' ),
					'false' => esc_html__( 'False', 'karigari' ),
				),

			)
		);

		$this->add_control(
			'arrow',
			array(
				'label'     => esc_html__( 'Arrow', 'karigari' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'true',
				'condition' => array(
					'portfolio-type' => 'slider',
				),
				'options'   => array(
					'true'  => esc_html__( 'True', 'karigari' ),
					'false' => esc_html__( 'False', 'karigari' ),
				),

			)
		);

		$this->add_control(
			'margin',
			array(
				'label'     => esc_html__( 'Margin', 'karigari' ),
				'type'      => Controls_Manager::SLIDER,
				'condition' => array(
					'portfolio-type' => 'slider',
				),
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 30,
					],
				],
				'default'   => array(
					'size' => 15,
				),

			)
		);

		$this->add_control(
			'speed',
			array(
				'label'     => esc_html__( 'Speed', 'karigari' ),
				'type'      => Controls_Manager::TEXT,
				'default'   => '1500',
				
			)
		);

		$this->end_controls_section();


		$this->start_controls_section(
			'portfolio-font',
			array(
				'label' => esc_html__('Portfolio Font', 'karigari'),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'     => 'portfolio_01',
				'label' => esc_html__('Title Font', 'karigari'),
				'selector' => '{{WRAPPER}} .tt-portfolio-thumbnail span, .portfolio-grid.Portfolio-style-1 a span, .portfolio-grid.Portfolio-style-2 a span, .swiper.portfolio-carousel .tt-portfolio-thumbnail .tt-portfolio-details h2',
			)
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'progressbar_style',
			array(
				'label' => esc_html__('Progressbar', 'karigari'),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);


		$this->add_control(
			'title-color',
			array(
				'label'     => esc_html__('Title Color', 'karigari'),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .tt-portfolio-thumbnail span, .portfolio-grid.Portfolio-style-1 a span, .portfolio-grid.Portfolio-style-2 a span, .swiper.portfolio-carousel .tt-portfolio-thumbnail .tt-portfolio-details h2' => 'color: {{VALUE}};',
				),
			)
		);
		$this->add_control(
			'title-hv-color',
			array(
				'label'     => esc_html__('Title Hover Color', 'karigari'),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .tt-portfolio-thumbnail span:hover, .portfolio-grid.Portfolio-style-1 a:hover span, .portfolio-grid.Portfolio-style-2 a:hover span, .swiper.portfolio-carousel .tt-portfolio-thumbnail .tt-portfolio-details h2:hover' => 'color: {{VALUE}};',
				),
			)
		);
		
		$this->end_controls_section();

	}

	/**
	 * Render Portfolio widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();
		$paged    = ( get_query_var( 'paged' ) ) ? get_query_var( 'paged' ) : 1;

		$args = array(
			'post_type'        => 'tt-portfolio',
			'post_status'      => 'publish',
			'posts_per_page'   => $settings['post-number'],
			'order'            => $settings['post-order'],
			'suppress_filters' => 0,
		);

		$the_query = new \WP_Query( $args );

		global $post;

		$this->add_render_attribute( 'owl-setting', 'data-dots', $settings['dots'] );
		$this->add_render_attribute( 'owl-setting', 'data-nav', $settings['arrow'] );
		$this->add_render_attribute( 'owl-setting', 'data-desk', $settings['desk-number'] );
		$this->add_render_attribute( 'owl-setting', 'data-laptop', $settings['laptop-number'] );
		$this->add_render_attribute( 'owl-setting', 'data-tablet', $settings['tablet-number'] );
		$this->add_render_attribute( 'owl-setting', 'data-mobile', $settings['mobile-number'] );
		$this->add_render_attribute( 'owl-setting', 'data-autoplay', $settings['autoplay'] );
		$this->add_render_attribute( 'owl-setting', 'data-loop', $settings['loop'] );
		$this->add_render_attribute( 'owl-setting', 'data-margin', $settings['margin']['size'] );

		$this->add_render_attribute(
			'attribute-owl',
			[
				'class' => [ 'owl-carousel portfolio-carousel', $settings['portfolio-style'] ]
			]
		);

		$masonary = "";

		if( $settings['portfolio-type'] == 'grid'){
			$masonary = 'portfolio-grid';
		} else {
			$masonary = 'portfolio-masonary';
		}

		$this->add_render_attribute(
			'attribute',
			[
				'class' => [ $masonary, $settings['portfolio-style'] ]
			]
		);

			$output = '';
			if ( 'slider' === $settings['portfolio-type'] ) {
				$output .= '<div '. $this->get_render_attribute_string( 'attribute-owl' ) .' ' . $this->get_render_attribute_string( 'owl-setting' ) . ' >';

					if ( $the_query->have_posts() ) {
						while ( $the_query->have_posts() ) {
							$the_query->the_post();

							if ( has_post_thumbnail() ) {
								$output .= '<div class="tt-portfolio-thumbnail">';
									$output .= '<div class="tt-portfolio-thumbnail-img grid-item">';
										$output .= '<a href="' . get_permalink() . '">';
											$output .= get_the_post_thumbnail();
											$output .= '<span>'.get_the_title().'</span>';
										$output .= '</a>';
									$output .='</div>';
								$output .='</div>';
							}
						}
						wp_reset_postdata();
					}

				$output .= '</div>';
			}



			if ( 'grid' === $settings['portfolio-type'] ) {
				$output .= '<div '. $this->get_render_attribute_string( 'attribute' ) .'>';
				$output .= '<div class="row grid">';
					if ( $the_query->have_posts() ) {
						while ( $the_query->have_posts() ) {
							$the_query->the_post();

							if ( has_post_thumbnail() ) {
								$output .= '<div class="tt-portfolio-thumbnail col-sm-4 grid-item">';
									$output .= '<a href="' . get_permalink() . '">';
									$output .= '<div class="tt-portfolio-thumbnail-img">';
										$output .= get_the_post_thumbnail();
								$output .='</div>';
										$output .= '<span>'.get_the_title().'</span>';
									
									$output .= '</a>';
								$output .='</div>';
							}
						}
					}
					wp_reset_postdata();
				$output .= '</div>';
				$output .= '</div>';
			}

		
		echo $output; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped

		if ( Plugin::$instance->editor->is_edit_mode() ) :
			?>
			<script>
				jQuery('.portfolio-carousel').each(function() {
					var $carousel = jQuery(this);
					$carousel.owlCarousel({
						items: $carousel.data("desk"),
						loop: $carousel.data("loop"),
						margin: $carousel.data("margin"),
						stagePadding: $carousel.data("padding"),
						nav: $carousel.data("nav"),
						dots: $carousel.data("dots"),
						autoplay: $carousel.data("autoplay"),
						center: $carousel.data("center"),
						info: $carousel.data("info"),
						animateOut: 'fadeOut',
						autoplayTimeout: $carousel.data("autoplay-timeout"),
						navText: ["<i class='ti-angle-left'></i>", "<i class='ti-angle-right'></i>"],
						responsiveClass: true,
						responsive: {
							// breakpoint from 0 up
							0: {
								items: 1
							},
							// breakpoint from 320 up
							480: {
								items: $carousel.data("mobile")
							},
							// breakpoint from 576 up
							576: {
								items: $carousel.data("mobile")
							},
							// breakpoint from 992 up
							992: {
								items: $carousel.data("tablet")
							},
							// breakpoint from 1200 up
							1200: {
								items: $carousel.data("laptop")
							},
							// breakpoint from 1400 up
							1400: {
								items:$carousel.data("desk")
							}
						}
					});
				});
			</script>
			<?php
		endif;
	}
}
Plugin::instance()->widgets_manager->register_widget_type( new \Elementor\Widget_Portfolio() );
