<?php
/**
 * Widget API: Elementer Best Sellers Product Widget
 *
 * @package karigari
 * @subpackage Widgets
 * @since 1.0.0
 */

namespace Elementor;
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Elementor Best Sellers Product widget.
 * Elementor widget that displays a Best Sellers Product with the ability to control every
 * aspect of the Best Sellers Product design.
 * @since 1.0.0
 */
class Widget_karigari_Best_Sellers_Product extends Widget_Base {
	/**
	 * Get widget name.
	 * Retrieve Best Sellers Product widget name.
	 * @since 1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return esc_html__( 'Best Sellers Product', 'karigari' );
	}

	/**
	 * Get widget title.
	 * Retrieve Best Sellers Product widget title.
	 * @since 1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Best Sellers Product', 'karigari' );
	}

	/**
	 * Get widget icon.
	 * Retrieve Best Sellers Product widget icon.
	 * @since 1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_categories() {
		return array( 'karigari' );
	}

	/**
	 * Get widget icon.
	 * Retrieve heading widget icon.
	 * @since 1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-image';
	}

	/**
	 * Register Best Sellers Product widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @since 1.0.0
	 * @access protected
	 */
	// @codingStandardsIgnoreStart
	protected function register_controls() {
		// @codingStandardsIgnoreEnd
		$this->start_controls_section(
			'Best Sellers Product',
			array(
				'label' => esc_html__( 'Best Sellers Product', 'karigari' ),
			)
		);


		$this->add_control(
			'product-order',
			array(
				'label'   => esc_html__( 'Product Order', 'karigari' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'ASC',
				'options' => array(
					'DESC' => esc_html__( 'Descending', 'karigari' ),
					'ASC'  => esc_html__( 'Ascending', 'karigari' ),

				),
			)
		);

		$this->add_control(
			'display-stock-progress',
			array(
				'label'     => esc_html__( 'stock-progress', 'karigari' ),
				'type'      => Controls_Manager::SWITCHER,
				'default'   => 'no',
				'yes'       => esc_html__( 'yes', 'karigari' ),
				'no'        => esc_html__( 'no', 'karigari' ),
			)
		);
		
		$this->add_control(
			'stock-progress',
			array(
				'label'       => esc_html__( 'stock-progress', 'karigari' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'condition'   => array(
					'display-stock-progress' => 'yes',
				),
				'label_block' => true,
			)
		);



		$this->end_controls_section();

		$this->start_controls_section(
			'carousel',
			array(
				'label'     => esc_html__( 'Carousel', 'karigari' ),
			)
		);

		$this->add_control(
			'desk',
			array(
				'label'       => esc_html__( 'Desktop', 'karigari' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'label_block' => true,
				'default'     => '3',
			)
		);

		$this->add_control(
			'laptop',
			array(
				'label'       => esc_html__( 'Laptop', 'karigari' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'label_block' => true,
				'default'     => '3',
			)
		);

		$this->add_control(
			'tablet',
			array(
				'label'       => esc_html__( 'Tablet', 'karigari' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'label_block' => true,
				'default'     => '3',
			)
		);

		$this->add_control(
			'mobile',
			array(
				'label'       => esc_html__( 'Mobile', 'karigari' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'label_block' => true,
				'default'     => '3',
			)
		);

		$this->add_control(
			'autoplay',
			array(
				'label'     => esc_html__( 'Autoplay', 'karigari' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'false',
				'options'   => array(
					'true'  => esc_html__( 'True', 'karigari' ),
					'false' => esc_html__( 'False', 'karigari' ),
				),
				
			)
		);
		

		$this->add_control(
			'loop',
			array(
				'label'     => esc_html__( 'Loop', 'karigari' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'true',
				'options'   => array(
					'true'  => esc_html__( 'True', 'karigari' ),
					'false' => esc_html__( 'False', 'karigari' ),
				),
			)
		);

		$this->add_control(
			'dots',
			array(
				'label'     => esc_html__( 'Dots', 'karigari' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'true',
				'options'   => array(
					'true'  => esc_html__( 'True', 'karigari' ),
					'false' => esc_html__( 'False', 'karigari' ),
				),
			)
		);

		$this->add_control(
			'arrow',
			array(
				'label'     => esc_html__( 'Arrow', 'karigari' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'true',
				'options'   => array(
					'true'  => esc_html__( 'True', 'karigari' ),
					'false' => esc_html__( 'False', 'karigari' ),
				),
			)
		);

		$this->add_control(
			'margin',
			array(
				'label'     => esc_html__( 'Margin', 'karigari' ),
				'type'      => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 30,
					],
				],
				'default'   => array(
					'size' => 15,
				),

			)
		);
		$this->add_control(
			'speed',
			array(
				'label'     => esc_html__( 'Speed', 'karigari' ),
				'type'      => Controls_Manager::TEXT,
				'default'   => '1500',
				
			)
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'sellers-Product_style',
			array(
				'label' => esc_html__( 'Best Sellers Product Style', 'karigari' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_control(
			'title_color',
			array(
				'label'     => esc_html__( 'Title Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .karigari-post .post-details .post-title .post-min-title' => 'color: {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'title_hover_color',
			array(
				'label'     => esc_html__( 'Title Hover Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .karigari-post .post-details .post-title .post-min-title a:hover' => 'color: {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'category_color',
			array(
				'label'     => esc_html__( 'Category Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .karigari-post .post-details .post-category a' => 'color: {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'category_hover_color',
			array(
				'label'     => esc_html__( 'Category Hover Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .karigari-post .post-details .post-category a:hover' => 'color: {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'category_bg_color',
			array(
				'label'     => esc_html__( 'Category BG Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .karigari-post .post-details .post-category a' => 'background: {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'category_bg_hover_color',
			array(
				'label'     => esc_html__( 'Category BG Hover Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .karigari-post .post-details .post-category a:hover' => 'background: {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'description-color',
			array(
				'label'     => esc_html__( 'Description Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .karigari-post .post-details .post-excerpt p' => 'color: {{VALUE}};',
				),
			)
		);
		
		$this->end_controls_section();
	}

	/**
	 * Render Best Sellers Product widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();
		global $wpml, $product;
	
		$paged = ( get_query_var( 'paged' ) ) ? get_query_var( 'paged' ) : 1;

		$this->add_render_attribute(
			'category-carousel',
			[
				'class' => ['swiper selling-swiper product-best-sellers swiper-arrow swiper-bul' ]
			]
		);

		$this->add_render_attribute( 'carousel-setting', 'class', 'swiper-wrapper');
		$this->add_render_attribute( 'carousel-setting', 'data-dots', $settings['dots'] );
		$this->add_render_attribute( 'carousel-setting', 'data-nav', $settings['arrow'] );
		$this->add_render_attribute( 'carousel-setting', 'data-desk', $settings['desk'] );
		$this->add_render_attribute( 'carousel-setting', 'data-laptop', $settings['laptop'] );
		$this->add_render_attribute( 'carousel-setting', 'data-tablet', $settings['tablet'] );
		$this->add_render_attribute( 'carousel-setting', 'data-mobile', $settings['mobile'] );
		$this->add_render_attribute( 'carousel-setting', 'data-autoplay', $settings['autoplay'] );
		$this->add_render_attribute( 'carousel-setting', 'data-loop', $settings['loop'] );
		$this->add_render_attribute( 'carousel-setting', 'data-speed', $settings['speed'] );
		$this->add_render_attribute( 'carousel-setting', 'data-margin', $settings['margin']['size'] );

		$devide = 1;

		$query = array(
			'post_type'           => 'product',
			'post_status'         => 'publish',
			'ignore_sticky_posts' => 1,
			'meta_key' 			  => 'total_sales',
			'order'               => 'desc',
			'orderby' 			  => 'meta_value_num',
			'paged'               => $paged,
		);
		$loop = new \WP_Query($query); ?>

				<div <?php echo $this->get_render_attribute_string( 'category-carousel' ); ?> data-id="selling-swiper" id="selling-swiper" >
					<div <?php echo $this->get_render_attribute_string( 'carousel-setting' ); ?> >

					<?php if ( $loop->have_posts() ) {
						while ( $loop->have_posts() ) : $loop->the_post();

							if( $devide%2 != 0 ){
							echo '<div class="swiper-slide">';
								echo '<div class="item">';
							}
					?>
										
						<section <?php wc_product_class( '', $product ); ?>>
							<div class="product-content-wrap">
								<div class="row m-0">
									<div class="col-4 p-0">
										<?php
										/**
										 * Hook: woocommerce_thumb_wrap_before.
										 *
										 * @hooked woocommerce_thumb_wrap_before_content - 10
										 */
										do_action( 'woocommerce_thumb_wrap_before' );

										/**
										 * Hook: woocommerce_before_shop_loop_item_title.
										 *
										 * @hooked sale_badge_percentage - 10
										 * @hooked woocommerce_template_loop_product_thumbnail - 15
										 * @hooked woocommerce_template_loop_stock - 20
										 */
										do_action( 'woocommerce_before_shop_loop_item_title' );


										/**
										 * Hook: woocommerce_thumb_wrap_after.
										 *
										 * @hooked woocommerce_thumb_wrap_after_content - 10
										 */
										do_action( 'woocommerce_thumb_wrap_after' );

										?>

									</div>
									<div class="col-8 p-0">
										<?php
										/**
										 * Hook: woocommerce_before_content.
										 *
										 * @hooked karigari_content_wrapper_before - 10
										 */
										do_action( 'woocommerce_before_content' );
			
										/**
										* Hook: woocommerce_product_brand_name.
										*
										* @hooked karigari_get_product_brand_name
										*/
										do_action( 'woocommerce_product_brand_name' );
			


										/**
										 * Hook: woocommerce_shop_loop_item_title.
										 *
										 * @hooked woocommerce_template_loop_product_title - 10
										 */
										do_action( 'woocommerce_shop_loop_item_title' );


										/**
										 * Hook: woocommerce_before_shop_loop_item_rating.
										 *
										 * @hooked woocommerce_template_loop_rating - 15
										 */
										do_action( 'woocommerce_before_shop_loop_item_rating' );


										/**
										 * Hook: woocommerce_after_shop_loop_item_title.
										 *
										 * @hooked woocommerce_template_loop_price - 10
										 */
										do_action( 'woocommerce_after_shop_loop_item_title' );


										if($settings['display-stock-progress'] == "yes"){
											do_action( 'woocommerce_stock_progressbar' );
										}
										

										?>
										<div class="content-wrap-btn">
											<?php
											/**
											 * Hook:  woocommerce_cart_button.
											 *
											 * @hooked product_add_to_cart - 10
											 */
											do_action( 'woocommerce_after_shop_loop_item' );

											/**
											 * Hook: woocommerce_product_button.
											 *
											 * @hooked product_wishlist_quickview_compare - 10
											 */
											do_action( 'woocommerce_product_button' );


											/**
											* Hook: woocommerce_after_content.
											*
											* @hooked karigari_content_wrapper_after - 10
											*/
											do_action( 'woocommerce_after_content' );

											?>
										</div>
									</div>
								</div>
							</div>
						</section>
					
								


					<?php

						if( $devide%2 == 0 ){
							echo '</div>';
							echo '</div>';

							$devide = 0;
						}
						$devide++;

							
						endwhile;
						if( $devide%2 == 0 &&  $count >= 10 ){
							echo '</div>';
						}
					} else {
						echo esc_html__( 'No products found' );
					} ?>
				</div>
			</div>
			<?php
			if($settings['dots'] == "true"){ ?>
						<div class="swiper-pagination"></div>
					<?php } ?>
	
			<?php		if($settings['arrow'] == "true"){ ?>
						<div class="swiper-navigation">
							<div class="swiper-button swiper-button-prev"><svg xmlns="http://www.w3.org/2000/svg" width="36" height="36" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2.5" stroke-linecap="round" stroke-linejoin="round" class="feather feather-chevron-left"><polyline points="15 18 9 12 15 6"></polyline></svg></div>
							<div class="swiper-button swiper-button-next"><svg xmlns="http://www.w3.org/2000/svg" width="36" height="36" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2.5" stroke-linecap="round" stroke-linejoin="round" class="feather feather-chevron-right"><polyline points="9 18 15 12 9 6"></polyline></svg></div>
						</div>
				<?php	} ?>


		<?php wp_reset_postdata(); ?>
		<!-- echo $output; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped -->
		<?php
		if ( Plugin::$instance->editor->is_edit_mode() ) {
			?>
			<script>

				if( jQuery('div').hasClass('selling-swiper') ){

					$this = jQuery('.swiper.selling-swiper');

					var desktop = $this.find( '.swiper-wrapper' ).data('desk');
					var laptop = $this.find( '.swiper-wrapper' ).data('laptop');
					var tablet = $this.find( '.swiper-wrapper' ).data('tablet');
					var mobile = $this.find( '.swiper-wrapper' ).data('mobile');
					var autoplay = $this.find( '.swiper-wrapper' ).data('autoplay');
					var loop = $this.find( '.swiper-wrapper' ).data('loop');
					var margin = $this.find( '.swiper-wrapper' ).data('margin');

					var next = '.'+jQuery(this).attr("data-id")+' '+'+'+".swiper-navigation .swiper-button-next";
					var prev = '.'+jQuery(this).attr("data-id")+' '+'+'+".swiper-navigation .swiper-button-prev";
					var pagination = '.'+jQuery(this).attr("data-id")+' '+'+'+".swiper-pagination";


					mySwiper = new Swiper('.swiper.selling-swiper', {
						spaceBetween: margin,
						loop: loop,
						autoplay: autoplay,
						
						breakpoints: {
							0: {
								slidesPerView: 	1,
								spaceBetween: margin,
							},
							// breakpoint from 480 up
							540: {
								slidesPerView: mobile,
							},
							// breakpoint from 576 up
							576: {
								slidesPerView: mobile,
							},
							// breakpoint from 992 up
							768: {
								slidesPerView: tablet,
							},
							// breakpoint from 1200 up
							1200: {
								slidesPerView: laptop,
							},
							// breakpoint from 1400 up
							1401: {
								slidesPerView: desktop,
							}
						},
						pagination: {
							el: pagination,
							clickable: true,
						},
						navigation: {
							nextEl: next,
							prevEl: prev,
						},
						
						});
				}

			</script>
		<?php
		}
	}
}
Plugin::instance()->widgets_manager->register_widget_type( new \Elementor\Widget_karigari_Best_Sellers_Product() );
