<?php
/**
 * Widget API: Elementer Product by Categories Widget
 *
 * @package karigari
 * @subpackage Widgets
 * @since 1.0.0
 */

namespace Elementor;
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
$product_categories = array();
$prod_categories = get_terms( 'product_cat', array(
	'orderby'    => 'name',
	'order'      => 'ASC',
	'parent'	 => 0,
	'hide_empty' => true
));
foreach( $prod_categories as $prod_cat ) :	
	$product_categories[] =$prod_cat->name;			
endforeach;

/**
 * Elementor Product by Categories widget.
 * Elementor widget that displays a Product by Categories with the ability to control every
 * aspect of the Product by Categories design.
 * @since 1.0.0
 */
class Widget_karigari_Product_by_categories extends Widget_Base {
	/**
	 * Get widget name.
	 * Retrieve Product by Categories widget name.
	 * @since 1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return esc_html__( 'Product By Categories', 'karigari' );
	}

	/**
	 * Get widget title.
	 * Retrieve Product by Categories widget title.
	 * @since 1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Product By Categories', 'karigari' );
	}

	/**
	 * Get widget icon.
	 * Retrieve Product by Categories widget icon.
	 * @since 1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_categories() {
		return array( 'karigari' );
	}

	/**
	 * Get widget icon.
	 * Retrieve heading widget icon.
	 * @since 1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-image';
	}

	/**
	 * Register Product by Categories widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @since 1.0.0
	 * @access protected
	 */
	// @codingStandardsIgnoreStart
	protected function register_controls() {

		// @codingStandardsIgnoreEnd
		$this->start_controls_section(
			'Product by Categories',
			array(
				'label' => esc_html__( 'Product by Categories', 'karigari' ),
			)
		);

		$this->add_control(
			'style',
			array(
				'label'   => esc_html__( 'Select Style', 'karigari' ),
				'type'    => Controls_Manager::SELECT,
				'options' => array(
					'style-1' => esc_html__( 'Style 1', 'karigari' ),
				),
				'default' => 'style-1',
			)
		);
	
	
		$this->add_control(
			'category-title',
			array(
				'label'       => esc_html__( 'Title', 'karigari' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'label_block' => true,
				'default' => esc_html__( 'Product by Categoriess', 'karigari' ),
			)
		);
		$this->add_control(
			'display-description',
			array(
				'label'   => esc_html__( 'Display Description', 'karigari' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'no',
				
				'yes'     => esc_html__( 'yes', 'karigari' ),
				'no'      => esc_html__( 'no', 'karigari' ),
			)
		);
		$this->add_control(
			'category-description',
			array(
				'label'       => esc_html__( 'Description', 'karigari' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'condition'   => array(
					'display-description' => 'yes',
				),
				'label_block' => true,
				'default' => esc_html__( 'Product by Categoriess', 'karigari' ),
			)
		);
		$this->add_control(
			'display-upper-title',
			array(
				'label'   => esc_html__( 'Display Upper Title', 'karigari' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'no',
				'yes'     => esc_html__( 'yes', 'karigari' ),
				'no'      => esc_html__( 'no', 'karigari' ),
			)
		);
		$this->add_control(
			'product-number',
			array(
				'label'       => esc_html__( 'Products per Page', 'karigari' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'label_block' => true,
				'default'     => '12',
			)
		);
		$this->add_control(
			'upper-title',
			array(
				'label'       => esc_html__( 'Upper Title', 'karigari' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => array(
					'active' => true,
				),
				'condition'   => array(
					'display-upper-title' => 'yes',
				),
				'placeholder' => esc_html__( 'Enter your title', 'karigari' ),
				'default'     => esc_html__( 'Add Your Heading Text Here', 'karigari' ),
			)
		);
		
		$this->add_control(
			'owl-style',
			array(
				'label'   => esc_html__( 'Carousel Style', 'karigari' ),
				'type'    => Controls_Manager::SELECT,
				'options' => array(
					'home-default' => esc_html__( 'Row 1', 'karigari' ),
					'home-morden' => esc_html__( 'Row 2', 'karigari' ),
				),
				'default' => 'home-default',
			)
		);


		$this->add_control(
			'hover-style',
			array(
				'label'   => esc_html__( 'Select Product Style', 'karigari' ),
				'type'    => Controls_Manager::SELECT,
				'options' => array(
					'product-layout-default' => esc_html__( 'Default', 'karigari' ),
				),
				'default' => 'product-layout-default',
			)
		);


		$repeater = new Repeater();

		$repeater->add_control(
			'taxonomies',
			array(
				'label' 	=> esc_html__( 'Select Categories', 'plugin-name' ),
				'type' 		=>Controls_Manager::SELECT,
				'multiple' 	=> true,
				'options' 	=> $this->get_product_categories(),
			)
		);

		$repeater->add_control(
			'product-number',
			array(
				'label'       => esc_html__( 'Products per Page', 'karigari' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'label_block' => true,
				'default'     => '12',
			)
		);


		$this->add_control(
			'categories-tabs',
			array(
				'label'  => esc_html__( 'Categories Items', 'tt' ),
				'type'   => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
			)
		);

		$this->add_control(
			'direction',
			array(
				'label'   => esc_html__( 'Direction', 'karigari' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'ASC',
				'options' => array(
					'horizontal' => esc_html__( 'Horizontal', 'karigari' ),
				),
				'default' 	=> 'horizontal',
			)
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'owl',
			array(
				'label'     => esc_html__( 'Carousel', 'karigari' ),
			)
		);

		$this->add_control(
			'desk-number',
			array(
				'label'       => esc_html__( 'Desktop', 'karigari' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'label_block' => true,
				'default'     => '4',
			)
		);

		$this->add_control(
			'laptop-number',
			array(
				'label'       => esc_html__( 'Laptop', 'karigari' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'label_block' => true,
				'default'     => '4',
			)
		);

		$this->add_control(
			'tablet-number',
			array(
				'label'       => esc_html__( 'Tablet', 'karigari' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'label_block' => true,
				'default'     => '3',
			)
		);

		$this->add_control(
			'mobile-number',
			array(
				'label'       => esc_html__( 'Mobile', 'karigari' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'label_block' => true,
				'default'     => '2',
			)
		);

		$this->add_control(
			'autoplay',
			array(
				'label'     => esc_html__( 'Autoplay', 'karigari' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'true',
				'options'   => array(
					'true'  => esc_html__( 'True', 'karigari' ),
					'false' => esc_html__( 'False', 'karigari' ),
				),
			)
		);

		$this->add_control(
			'loop',
			array(
				'label'     => esc_html__( 'Loop', 'karigari' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'false',
				'options'   => array(
					'true'  => esc_html__( 'True', 'karigari' ),
					'false' => esc_html__( 'False', 'karigari' ),
				),
			)
		);

		$this->add_control(
			'dots',
			array(
				'label'     => esc_html__( 'Dots', 'karigari' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'true',
				'options'   => array(
					'true'  => esc_html__( 'True', 'karigari' ),
					'false' => esc_html__( 'False', 'karigari' ),
				),
			)
		);

		$this->add_control(
			'arrow',
			array(
				'label'     => esc_html__( 'Arrow', 'karigari' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'true',
				'options'   => array(
					'true'  => esc_html__( 'True', 'karigari' ),
					'false' => esc_html__( 'False', 'karigari' ),
				),
			)
		);

		$this->add_control(
			'margin',
			array(
				'label'     => esc_html__( 'Margin', 'karigari' ),
				'type'      => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 30,
					],
				],
				'default'   => array(
					'size' => 15,
				),
			)
		);

		$this->add_control(
			'speed',
			array(
				'label'     => esc_html__( 'Speed', 'karigari' ),
				'type'      => Controls_Manager::TEXT,
				'default'   => '1500',
				
			)
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'product_by_cat_font',
			array(
				'label' => esc_html__( 'Product By Category Font', 'karigari' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'     => 'pro_by_cat_typography',
				'label' => esc_html__( 'Title Font', 'karigari' ),
				'selector' => '{{WRAPPER}} .product .woocommerce-loop-product__title',
			)
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'     => 'pro_by_cat_typography_01',
				'label' => esc_html__( 'Price Font', 'karigari' ),
				'selector' => '{{WRAPPER}} .product .price .amount bdi, .product .price ins',
			)
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'     => 'pro_by_cat_typography_02',
				'label' => esc_html__( 'Section Title Font', 'karigari' ),
				'selector' => '{{WRAPPER}} .section-heading',
			)
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'     => 'pro_by_cat_typography_03',
				'label' => esc_html__( 'Section Sub Title Font', 'karigari' ),
				'selector' => '{{WRAPPER}} .product-by-category .title-wrap .product-title .tt-section-sab',
			)
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'     => 'pro_by_cat_typography_04',
				'label' => esc_html__( 'Section Description Font', 'karigari' ),
				'selector' => '{{WRAPPER}} .product-by-category .title-wrap .product-title .section-description',
			)
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'     => 'pro_by_cat_typography_05',
				'label' => esc_html__( 'Tab Font', 'karigari' ),
				'selector' => '{{WRAPPER}} .product-by-category .ui-tabs-nav .ui-tabs-tab a',
			)
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'     => 'pro_by_cat_typography_06',
				'label' => esc_html__( 'Rating Font', 'karigari' ),
				'selector' => '{{WRAPPER}} .product .star-rating span::before',
			)
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'     => 'pro_by_cat_typography_08',
				'label' => esc_html__( 'Timer Text Font', 'karigari' ),
				'selector' => '{{WRAPPER}} .thumbnail-wrap .timer>div>div.text',
			)
		);
		$this->end_controls_section();


		$this->start_controls_section(
			'Product_by_Categories_style',
			array(
				'label' => esc_html__( 'Product by Categories Style', 'karigari' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		
		
		$this->add_control(
			'title_color',
			array(
				'label'     => esc_html__( 'Title Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .product .woocommerce-loop-product__title' => 'color: {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'title_hover_color',
			array(
				'label'     => esc_html__( 'Title Hover Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .product .woocommerce-loop-product__title:hover' => 'color: {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'price_color',
			array(
				'label'     => esc_html__( 'Price Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .product .price .amount bdi, .product .price ins' => 'color: {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'section-title-color',
			array(
				'label'     => esc_html__( 'Section Title Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .product_catagories .title-wrap .product-title .tt-section-sab' => 'color: {{VALUE}};',
				),
			)
		);
		$this->add_control(
			'section-heading-color',
			array(
				'label'     => esc_html__( 'Section Heading Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .section-heading' => 'color: {{VALUE}};',
				),
			)
		);
		
		$this->add_control(
			'section-upper-color',
			array(
				'label'     => esc_html__( 'Section Upper Title Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .product-by-category .title-wrap .product-title .tt-section-sab' => 'color: {{VALUE}};',
				),
			)
		);
		
		$this->add_control(
			'section-description-color',
			array(
				'label'     => esc_html__( 'Section Description Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .product-by-category .title-wrap .product-title .section-description' => 'color: {{VALUE}};',
				),
			)
		);
		$this->add_control(
			'active-tab',
			array(
				'label'     => esc_html__( 'Active Tab', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .product-by-category .ui-tabs-nav .ui-tabs-tab.ui-state-active a' => 'color: {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'tab-color-before-active',
			array(
				'label'     => esc_html__( 'Tab Color Before Active', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .product-by-category .ui-tabs-nav .ui-tabs-tab a::before' => 'background: {{VALUE}};',
				),
			)
		);
		$this->add_control(
			'tab-color',
			array(
				'label'     => esc_html__( 'Tab Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .product-by-category .ui-tabs-nav .ui-tabs-tab a' => 'color: {{VALUE}};',
				),
			)
		);
		$this->add_control(
			'rating-color',
			array(
				'label'     => esc_html__( 'Rating Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .product .star-rating span::before' => 'color: {{VALUE}};',
				),
			)
		);
		$this->add_control(
			'timer-counter-color',
			array(
				'label'     => esc_html__( 'Timer Counter Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .list-content .timer>div>p, .thumbnail-wrap .timer>div>p' => 'color: {{VALUE}};',
				),
			)
		);
		$this->add_control(
			'timer-text-color',
			array(
				'label'     => esc_html__( 'Timer Text Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .thumbnail-wrap .timer>div>div.text' => 'color: {{VALUE}};',
				),
			)
		);
		$this->end_controls_section();
	}

	protected function get_product_categories() {
	
		$taxonomies = get_categories(  
			array( 
				'taxonomy' => 'product_cat',
				'orderby' => 'name',
			)
		);

		$options = [ '' => '' ];

		foreach ( $taxonomies as $taxonomy ) {
			$options[ $taxonomy->cat_ID ] = $taxonomy->name;
		}

		return $options;
	}

	/**
	 * Render Product by Categories widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();
		global $wpml;

		$tabs = $this->get_settings_for_display( 'categories-tabs' );

		$paged    = ( get_query_var( 'paged' ) ) ? get_query_var( 'paged' ) : 1;

		$this->add_render_attribute( 'carousel-setting', 'class', 'swiper-wrapper' );
		$this->add_render_attribute( 'carousel-setting', 'data-direction', $settings['direction'] );
		$this->add_render_attribute( 'carousel-setting', 'data-dots', $settings['dots'] );
		$this->add_render_attribute( 'carousel-setting', 'data-nav', $settings['arrow'] );
		$this->add_render_attribute( 'carousel-setting', 'data-desk', $settings['desk-number'] );
		$this->add_render_attribute( 'carousel-setting', 'data-laptop', $settings['laptop-number'] );
		$this->add_render_attribute( 'carousel-setting', 'data-tablet', $settings['tablet-number'] );
		$this->add_render_attribute( 'carousel-setting', 'data-mobile', $settings['mobile-number'] );
		$this->add_render_attribute( 'carousel-setting', 'data-autoplay', $settings['autoplay'] );
		$this->add_render_attribute( 'carousel-setting', 'data-loop', $settings['loop'] );
		$this->add_render_attribute( 'carousel-setting', 'data-speed', $settings['speed'] );
		$this->add_render_attribute( 'carousel-setting', 'data-margin', $settings['margin']['size'] );

		$this->add_render_attribute(
			'attribute',
			[
				'class' => ['product-by-category' , $settings['style'] ]
			]
		);
		$this->add_render_attribute(
			'attribute',
			[
				'class' => ['product-by-category' , $settings['hover-style'] ]
			]
		);
		$i=1;
		$output = '';

		$prod_categories = get_terms( 'product_cat', array(
			'orderby'    => 'name',
			'order'      => 'ASC',
			// 'parent'	 => 0,
			'hide_empty' => true
		));
		?>

			<div id="product-by-categories" <?php echo $this->get_render_attribute_string( 'attribute' ); ?>>
				<div class="title-wrap">
					<?php
					
					if( ! empty( $settings['category-title'] ) ){ ?>
						<div class="product-title">
						<?php if ( $settings['display-upper-title'] == 'yes' ) { ?>
			<span class="tt-section-sab"><?php echo sprintf( '%1$s', esc_html( $settings['upper-title'] ) ); ?></span>
			<?php } ?>
							<h2 class="section-heading"><?php echo $settings['category-title']; ?></h2>
							<?php if ( $settings['display-description'] == 'yes' ) { ?>
							<div class="section-description"><?php echo $settings['category-description']; ?></div>
							<?php } ?>
						</div>
					<?php } ?>
					<ul>
						<?php
						foreach ( $tabs as $index => $item ) {
							$term_id = $item['taxonomies'];
							if( !empty( $term_id ) ){
								
								?>
								<li><a href="#<?php echo 'productby-'.$item['taxonomies']; ?>"><?php echo get_term( $term_id )->name; ?></a></i>
								<?php
							}
						} ?>
					</ul>
					
				</div>
	
				<?php
				foreach ( $tabs as $index => $item ) {
					$product_per_page = $item['product-number'];
					if( !empty( $item['taxonomies'] ) ){
						$devide = 1;
						$args = array(
							'post_type'             => 'product',
							'post_status'           => 'publish',
							'ignore_sticky_posts'   => 1,
							'posts_per_page'        => $product_per_page,
							'tax_query'             => array(
								array(
									'taxonomy'  => 'product_cat',
									'field'     => 'term_id',
									'terms'     =>  $item['taxonomies'],
									'operator'  => 'IN',
								)
							)
						);

						$loop = new \WP_Query($args);
						$count = $loop->found_posts;	
						global $product;
						
						?>
						<div class="swiper productBy-category productby-<?php echo $item['taxonomies']; ?>" data-id = "productby-<?php echo $item['taxonomies']; ?>" id="productby-<?php echo $item['taxonomies']; ?>" >
							
							<div <?php echo $this->get_render_attribute_string( 'carousel-setting' ); ?> >
								<?php																
								if ( $loop->have_posts() ) {
									while ( $loop->have_posts() ) : $loop->the_post();
									echo '<div class="swiper-slide">';
										if( $count >= 8 && $settings['owl-style'] == "home-morden"){
						
											if( $devide%2 != 0 ){
												echo '<div class="item">';
											}
												if( $settings['hover-style'] == "product-layout-default" ){
													wc_get_template_part( 'content', 'product' );
												}
												/* echo '<span>'.$devide.'</span>'; */
						
											if( $devide%2 == 0 ){
												echo '</div>';
												$devide = 0;
											}
						
										} else {
											if( $settings['hover-style'] == "product-layout-default" ){
												wc_get_template_part( 'content', 'product' );
											}
										}
									echo '</div>';
								$devide++;
								endwhile;
									
								if( $devide%2 == 0 &&  $count >= 8 && $settings['owl-style'] == "home-morden"){
									echo '</div>';
								}
								} else {
									echo esc_html__( 'No products found' );
								}
								wp_reset_postdata(); ?>
							</div>
							<?php
										if( $settings['dots'] == "true"){
									?>
										<div class="swiper-pagination"></div>
									<?php
										}
									?>
									<?php
										if( $settings['arrow'] == "true"){
									?>
										<div class="swiper-navigation">
											<div class="swiper-button swiper-button-prev"><svg xmlns="http://www.w3.org/2000/svg" width="20" height="20" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round" class="feather feather-chevron-left"><polyline points="15 18 9 12 15 6"></polyline></svg></div>
											<div class="swiper-button swiper-button-next"><svg xmlns="http://www.w3.org/2000/svg" width="20" height="20" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round" class="feather feather-chevron-right"><polyline points="9 18 15 12 9 6"></polyline></svg></div>
										</div>
								</div>
									<?php
										}
									?>
						<?php
					}
				} ?>
				</div>
			<?php
		
		// echo $output; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
		
		if ( Plugin::$instance->editor->is_edit_mode() ) :
			?>
			<script>
				jQuery( "#product-by-categories" ).tabs();
				if( jQuery('div').hasClass('productBy-category') ){

						$this = jQuery('.swiper.productBy-category');


							var direction = $this.find( '.swiper-wrapper' ).data('direction');
					var desktop = $this.find( '.swiper-wrapper' ).data('desk');
					var laptop = $this.find( '.swiper-wrapper' ).data('laptop');
					var tablet = $this.find( '.swiper-wrapper' ).data('tablet');
					var mobile = $this.find( '.swiper-wrapper' ).data('mobile');
					var autoplay = $this.find( '.swiper-wrapper' ).data('autoplay');
					var loop = $this.find( '.swiper-wrapper' ).data('loop');
					var center = $this.find( '.swiper-wrapper' ).data('center');
					var speed = $this.find( '.swiper-wrapper' ).data('speed');
					var margin = $this.find( '.swiper-wrapper' ).data('margin');

					var next = '.'+jQuery(this).attr("data-id")+' '+".swiper-button-next";
					var prev = '.'+jQuery(this).attr("data-id")+' '+".swiper-button-prev";
					var pagination = '.'+jQuery(this).attr("data-id")+' '+".swiper-pagination";

						mySwiper = new Swiper('.swiper.productBy-category', {
							spaceBetween: margin,
						loop: loop,
						autoplay: autoplay,

						breakpoints: {
							0: {
									items: 	1
								},
								// breakpoint from 480 up
								480: {
									slidesPerView: 2,
								},
								// breakpoint from 576 up
								768: {
									slidesPerView: mobile,
								},
								// breakpoint from 992 up
								992: {
									slidesPerView: tablet,
								},
								// breakpoint from 1200 up
								1200: {
									slidesPerView: laptop,
								},
								// breakpoint from 1400 up
								1401: {
									slidesPerView: desktop,
								}
						},
						pagination: {
							el: pagination,
							clickable: true,
							type: "progressbar",
						},
						navigation: {
							nextEl: next,
							prevEl: prev,
						},
						});
				}
			</script>
			<?php
		endif;
	}
}
Plugin::instance()->widgets_manager->register_widget_type( new \Elementor\Widget_karigari_Product_by_categories() );
