<?php
/**
 * Widget API: Elementer Product Categories Widget
 *
 * @package karigari
 * @subpackage Widgets
 * @since 1.0.0
 */

namespace Elementor;
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Elementor categories widget.
 * Elementor widget that displays a categories with the ability to control every
 * aspect of the categories design.
 * @since 1.0.0
 */
class Widget_karigari_Categories extends Widget_Base {
	/**
	 * Get widget name.
	 * Retrieve categories widget name.
	 * @since 1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return esc_html__( 'Karigari Product Categories', 'karigari' );
	}

	/**
	 * Get widget title.
	 * Retrieve categories widget title.
	 * @since 1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Karigari Product Categories', 'karigari' );
	}

	/**
	 * Get widget icon.
	 * Retrieve categories widget icon.
	 * @since 1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_categories() {
		return array( 'karigari' );
	}

	/**
	 * Get widget icon.
	 * Retrieve heading widget icon.
	 * @since 1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-image';
	}

	/**
	 * Register categories widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @since 1.0.0
	 * @access protected
	 */
	// @codingStandardsIgnoreStart
	protected function register_controls() {
		// @codingStandardsIgnoreEnd
		$this->start_controls_section(
			'categories',
			array(
				'label' => esc_html__( 'Product Categories', 'karigari' ),
			)
		);

		$this->add_control(
			'category-Style',
			array(
				'label'   => esc_html__( 'Categories View', 'karigari' ),
				'type'    => Controls_Manager::SELECT,
				'options' => array(
					'category-carousel' => esc_html__( 'Category Carousel', 'karigari' ),
					'category-grid' => esc_html__( 'Category Grid', 'karigari' ),
				),
				'default' => 'category-carousel',
			)
		);

		$this->add_control(
			'product-Style',
			array(
				'label'   => esc_html__( 'Categories Style', 'karigari' ),
				'type'    => Controls_Manager::SELECT,
				'options' => array(
					'category-style1' => esc_html__( 'Category Style 1', 'karigari' ),
					'category-style2' => esc_html__( 'Category Style 2', 'karigari' ),
					'category-style3' => esc_html__( 'Category Style 3', 'karigari' ),
					'category-style4' => esc_html__( 'Category Style 4', 'karigari' ),
				),
				'default' => 'category-style2',
			)
		);

		$this->add_control(
			'taxonomies',
			array(
				'label' 	=> esc_html__( 'Select Categories', 'plugin-name' ),
				'type' 		=>Controls_Manager::SELECT2,
				'multiple' 	=> true,
				'options' 	=> $this->get_product_categories(),
			)
		);

		$this->add_control(
			'direction',
			array(
				'label'   => esc_html__( 'Direction', 'karigari' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'ASC',
				'options' => array(
					'horizontal' => esc_html__( 'Horizontal', 'karigari' ),
				),
				'default' 	=> 'horizontal',
			)
		);


		$this->add_control(
			'display-button-sub-title',
			array(
				'label'     => esc_html__( 'Usesub-title', 'karigari' ),
				'type'      => Controls_Manager::SWITCHER,
				'default'   => 'no',
				'yes'       => esc_html__( 'yes', 'karigari' ),
				'no'        => esc_html__( 'no', 'karigari' ),
			)
		);

		$this->add_control(
			'sub-title',
			array(
				'label'       => esc_html__( 'Sub title', 'karigari' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'condition'   => array(
					'display-button-sub-title' => 'yes',
				),
				'label_block' => true,
				'default'     => 'Exclusive Collection 2024',
			)
		);
		$this->add_control(
			'display_section_description',
			array(
				'label'     => esc_html__( 'Use Section Description', 'karigari' ),
				'type'      => Controls_Manager::SWITCHER,
				'default'   => 'no',
				'yes'       => esc_html__( 'yes', 'karigari' ),
				'no'        => esc_html__( 'no', 'karigari' ),
			)
		);
		$this->add_control(
			'section_description',
			array(
				'label'       => esc_html__( 'Description', 'karigari' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'condition'   => array(
					'display_section_description' => 'yes',
				),
				'label_block' => true,
				'default'     => 'The Summer Sale',
			)
		);
		$this->add_control(
			'display_section_title',
			array(
				'label'     => esc_html__( 'Use Section Title', 'karigari' ),
				'type'      => Controls_Manager::SWITCHER,
				'default'   => 'no',
				'yes'       => esc_html__( 'yes', 'karigari' ),
				'no'        => esc_html__( 'no', 'karigari' ),
			)
		);
		$this->add_control(
			'title',
			array(
				'label'       => esc_html__( 'Title', 'karigari' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'condition'   => array(
					'display_section_title' => 'yes',
				),
				'label_block' => true,
				'default'     => 'The Summer Sale',
			)
		);

		$this->add_control(
			'display-tag',
			array(
				'label'     => esc_html__( 'Use Tag', 'karigari' ),
				'type'      => Controls_Manager::SWITCHER,
				'default'   => 'no',
				'yes'       => esc_html__( 'yes', 'karigari' ),
				'no'        => esc_html__( 'no', 'karigari' ),
			)
		);

		$this->add_control(
			'tag',
			array(
				'label'       => esc_html__( 'Tag', 'karigari' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'condition'   => array(
					'display-tag' => 'yes',
				),
				'label_block' => true,
				'default'     => 'Big Sale',
			)
		);

		$this->add_control(
			'display-button',
			array(
				'label'     => esc_html__( 'Use Button', 'karigari' ),
				'type'      => Controls_Manager::SWITCHER,
				'default'   => 'no',
				'yes'       => esc_html__( 'yes', 'karigari' ),
				'no'        => esc_html__( 'no', 'karigari' ),
			)
		);

		$this->add_control(
			'btn-text',
			array(
				'label'       => esc_html__( 'Button Text', 'karigari' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'condition'   => array(
					'display-button' => 'yes',
				),
				'label_block' => true,
				'default'     => 'Big Sale',
			)
		);

		$this->add_control(
			'btn-link',
			array(
				'label'       => esc_html__( 'Button URL', 'karigari' ),
				'type'        => Controls_Manager::URL,
				'dynamic'     => array(
					'active' => true,
				),
				'condition'   => array(
					'display-button' => 'yes',
				),
				'placeholder' => esc_html__( 'https://your-link.com', 'karigari' ),
				'default'     => array(
					'url' => '#',
				),
			)
		);

		$this->add_control(
			'button-style',
			array(
				'label' 	=> esc_html__( 'Button Style', 'nora' ),
				'type' 		=>Controls_Manager::SELECT,
				'condition'   => array(
					'display-button' => 'yes',
				),
				'default' => 'rectangle',
				'options' => array(
					'circle' => esc_html__( 'Circle', 'nora' ),
					'rectangle' => esc_html__( 'Rectangle', 'nora' ),
				),
			)
		);


		$this->add_control(
			'display-button-view',
			array(
				'label'     => esc_html__( 'View All Use Button', 'karigari' ),
				'type'      => Controls_Manager::SWITCHER,
				'default'   => 'no',
				'yes'       => esc_html__( 'yes', 'karigari' ),
				'no'        => esc_html__( 'no', 'karigari' ),
			)
		);
		$this->add_control(
			'btn-text-view',
			array(
				'label'       => esc_html__( 'View All Button Text', 'karigari' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'condition'   => array(
					'display-button-view' => 'yes',
				),
				'label_block' => true,
				'default'     => 'Big Sale',
			)
		);



		$this->end_controls_section();

		$this->start_controls_section(
			'carousel',
			array(
				'label'     => esc_html__( 'Carousel', 'karigari' ),
			)
		);

		$this->add_control(
			'desk',
			array(
				'label'       => esc_html__( 'Desktop', 'karigari' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'label_block' => true,
				'default'     => '3',
			)
		);

		$this->add_control(
			'laptop',
			array(
				'label'       => esc_html__( 'Laptop', 'karigari' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'label_block' => true,
				'default'     => '3',
			)
		);

		$this->add_control(
			'tablet',
			array(
				'label'       => esc_html__( 'Tablet', 'karigari' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'label_block' => true,
				'default'     => '3',
			)
		);

		$this->add_control(
			'mobile',
			array(
				'label'       => esc_html__( 'Mobile', 'karigari' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'label_block' => true,
				'default'     => '3',
			)
		);

		$this->add_control(
			'autoplay',
			array(
				'label'     => esc_html__( 'Autoplay', 'karigari' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'false',
				'options'   => array(
					'true'  => esc_html__( 'True', 'karigari' ),
					'false' => esc_html__( 'False', 'karigari' ),
				),
			)
		);

		$this->add_control(
			'loop',
			array(
				'label'     => esc_html__( 'Loop', 'karigari' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'true',
				'options'   => array(
					'true'  => esc_html__( 'True', 'karigari' ),
					'false' => esc_html__( 'False', 'karigari' ),
				),
			)
		);

		$this->add_control(
			'center',
			array(
				'label'     => esc_html__( 'Center', 'karigari' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'true',
				'options'   => array(
					'true'  => esc_html__( 'True', 'karigari' ),
					'false' => esc_html__( 'False', 'karigari' ),
				),
			)
		);

		$this->add_control(
			'dots',
			array(
				'label'     => esc_html__( 'Dots', 'karigari' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'true',
				'options'   => array(
					'true'  => esc_html__( 'True', 'karigari' ),
					'false' => esc_html__( 'False', 'karigari' ),
				),
			)
		);

		$this->add_control(
			'arrow',
			array(
				'label'     => esc_html__( 'Arrow', 'karigari' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'true',
				'options'   => array(
					'true'  => esc_html__( 'True', 'karigari' ),
					'false' => esc_html__( 'False', 'karigari' ),
				),
			)
		);

		$this->add_control(
			'margin',
			array(
				'label'     => esc_html__( 'Margin', 'karigari' ),
				'type'      => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 30,
					],
				],
				'default'   => array(
					'size' => 15,
				),
			)
		);
		
		$this->add_control(
			'speed',
			array(
				'label'     => esc_html__( 'Speed', 'karigari' ),
				'type'      => Controls_Manager::TEXT,
				'default'   => '1500',
			)
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'categories_font',
			array(
				'label' => esc_html__( 'Category Font', 'karigari' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'     => 'pro_cat_content_typography_01',
				'label' => esc_html__( 'Section Title Font', 'karigari' ),
				'selector' => '{{WRAPPER}} .Categories .product-category.category-slider .categories-text .categories-title',
			)
		);
		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'     => 'pro_cat_content_typography_02',
				'label' => esc_html__( 'Section Description Font', 'karigari' ),
				'selector' => '{{WRAPPER}} .Categories .product-category.category-slider .categories-text .categories-description',
			)
		);
		

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'     => 'tag_typography',
				'label' => esc_html__( 'Tag Font', 'karigari' ),
				'selector' => '{{WRAPPER}} .Categories .product-category.category-slider .wpcategories-content .categories-tag, .Blog-section-title .text-tag, .tt-section-title .text-tag, .title-wrap .product-title .title-text-tag ',
			)
		);
		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'     => 'desc_typography_01',
				'label' => esc_html__( 'Section Sub Title Font', 'karigari' ),
				'selector' => '{{WRAPPER}} .Categories .product-category.category-slider .wpcategories-content .categories-sub-title',
			)
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'     => 'pro_cat_content_typography_03',
				'label' => esc_html__( 'Section Title Font', 'karigari' ),
				'selector' => '{{WRAPPER}} .product-category.category-slider .categories-text .categories-title',
			)
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'     => 'desc_typography',
				'label' => esc_html__( 'Counter Font', 'karigari' ),
				'selector' => '{{WRAPPER}} .cat_desc .wpcat-content .cat_total_product',
			)
		);
		

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'     => 'btn_typography',
				'label' => esc_html__( 'Button Font', 'karigari' ),
				'selector' => '{{WRAPPER}} .Categories .product-category.category-slider .wpcategories-content .button-categories-wrap a',
			)
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'     => 'title_typography',
				'label' => esc_html__( 'Title Font', 'karigari' ),
				'selector' => '{{WRAPPER}} .category-style4 .wpcat-content .cat_name a, .category-style2 .wpcat-content .cat_name a',
			)
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'     => 'counter_typography',
				'label' => esc_html__( 'Counter Item Font', 'karigari' ),
				'selector' => '{{WRAPPER}} .category-style4 .wpcat-content .cat_total_product , .category-style2 .wpcat-content .cat_total_product',
			)
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'     => 'cat_btn_typography',
				'label' => esc_html__( 'Category Button Font', 'karigari' ),
				'selector' => '{{WRAPPER}} .swiper-slide .cat_group .cat_button',
			)
		);
		
		$this->end_controls_section();

		$this->start_controls_section(
			'categories_style',
			array(
				'label' => esc_html__( 'Categories Style', 'karigari' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_control(
			'title_color',
			array(
				'label'     => esc_html__( 'Title Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .cat_desc .wpcat-content .cat_name, .category-style4 .wpcat-content .cat_name a, .category-style2 .wpcat-content .cat_name a' => 'color: {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'title_hover_color',
			array(
				'label'     => esc_html__( 'Title Hover Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .cat_desc .wpcat-content .cat_name:hover' => 'color: {{VALUE}};',
				),
			)
		);
		
		$this->add_control(
			'style02-title_color',
			array(
				'label'     => esc_html__( 'Style02 Title Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .category-style2 .wpcat-content .cat_name' => 'color: {{VALUE}};',
				),
			)
		);
			$this->add_control(
			'style02-title_hover_color',
			array(
				'label'     => esc_html__( 'Style02 Title Hover Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .category-style2 .swiper-slide:hover .wpcat-content .cat_name a' => 'color: {{VALUE}};',
				),
			)
		);
		
		$this->add_control(
			'description-color',
			array(
				'label'     => esc_html__( 'Count Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .cat_desc .wpcat-content .cat_total_product' => 'color: {{VALUE}};',
				),
			)
		);
		$this->add_control(
			'style_view_button_hover_color',
			array(
				'label'     => esc_html__( 'Style View Button Hover Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .swiper-slide .cat_group .cat_button .view_all_button.btn.btn-primary::after' => 'background: {{VALUE}};',
				),
			)
		);
		
$this->add_control(
			'image-after-color',
			array(
				'label'     => esc_html__( 'Image After Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .cat_desc:hover .cat_image::after' => 'border-color: {{VALUE}};',
				),
			)
		);
		$this->add_control(
			'tag-color',
			array(
				'label'     => esc_html__( 'Tag Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .Categories .product-category.category-slider .wpcategories-content .categories-tag ' => ' color: {{VALUE}};',
				),
			)
		);
		$this->add_control(
			'cat-desc-color-after',
			array(
				'label'     => esc_html__( 'Cat Desc Color After', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .cat_desc .cat_image .cat_image_box::before ' => ' background: {{VALUE}};',
				),
			)
		);
		$this->add_control(
			'prograssbar-color',
			array(
				'label'     => esc_html__( 'Catagories progressbar color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .Categories .product-category.category-slider .swiper-pagination-progressbar.swiper-pagination-horizontal' => ' background: {{VALUE}};',
				),
			)
		);
		$this->add_control(
			'prograssbar-color-fill',
			array(
				'label'     => esc_html__( 'Catagories progressbar color Fill', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .Categories .swiper-pagination-progressbar .swiper-pagination-progressbar-fill' => ' background: {{VALUE}};',
				),
			)
		);
		$this->add_control(
			'discription-color',
			array(
				'label'     => esc_html__( 'Discription Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .cat_desc .wpcat-content .cat-description' => ' color: {{VALUE}};',
				),
			)
		);
		$this->add_control(
			'sub_title_color',
			array(
				'label'     => esc_html__( 'Sub Title Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .wpcategories-content .categories-sub-title' => 'color: {{VALUE}};',
				), 
			)
		);

		$this->add_control(
			'sub_description_color',
			array(
				'label'     => esc_html__( 'Sub description Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .wpcategories-content .categories-description' => 'color: {{VALUE}};',
				), 
			)
		);
		$this->add_control(
			'pro_cat_title_color',
			array(
				'label'     => esc_html__( 'Title Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .wpcategories-content .categories-title' => 'color: {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'button_bg_color',
			array(
				'label'     => esc_html__( 'Button Background Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .tt-categories .categories-text a.categories-button' => 'background: {{VALUE}};',
				),
			)
		);
		$this->add_control(
			'button_title_color',
			array(
				'label'     => esc_html__( 'Button Title Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .tt-categories .categories-text a.categories-button' => 'color: {{VALUE}};',
				), 
			)
		);
		$this->add_control(
			'button_bg_hv_color',
			array(
				'label'     => esc_html__( 'Button Background Hover Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .tt-categories .categories-text a.categories-button:after' => 'background: {{VALUE}};',
				),
			)
		);
		$this->add_control(
			'heading_text_color',
			array(
				'label'     => esc_html__( 'Heading Text Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .product-category.category-slider .categories-text .categories-title' => 'color: {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'button_title_hv__color',
			array(
				'label'     => esc_html__( 'Button Title Hover Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .tt-categories .categories-text a.categories-button:hover' => 'color: {{VALUE}};',
				), 
			)
		);
		$this->end_controls_section();
	}
	protected function get_product_categories() {
	
		$taxonomies = get_categories(  
			array( 
				'taxonomy' => 'product_cat',
				'orderby' => 'name',
			)
		);

		$options = [ '' => '' ];

		foreach ( $taxonomies as $taxonomy ) {
			$options[ $taxonomy->cat_ID ] = $taxonomy->name;
		}

		return $options;
	}

	/**
	 * Render categories widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {
		global $product;
		$settings = $this->get_settings();
		$paged    = ( get_query_var( 'paged' ) ) ? get_query_var( 'paged' ) : 1;

		$this->add_render_attribute( 'carousel-setting', 'class', 'swiper-wrapper' );
		$this->add_render_attribute( 'carousel-setting', 'data-direction', $settings['direction'] );
		$this->add_render_attribute( 'carousel-setting', 'data-dots', $settings['dots'] );
		$this->add_render_attribute( 'carousel-setting', 'data-nav', $settings['arrow'] );
		$this->add_render_attribute( 'carousel-setting', 'data-speed', $settings['speed'] );
		$this->add_render_attribute( 'carousel-setting', 'data-desk', $settings['desk'] );
		$this->add_render_attribute( 'carousel-setting', 'data-laptop', $settings['laptop'] );
		$this->add_render_attribute( 'carousel-setting', 'data-tablet', $settings['tablet'] );
		$this->add_render_attribute( 'carousel-setting', 'data-mobile', $settings['mobile'] );
		$this->add_render_attribute( 'carousel-setting', 'data-autoplay', $settings['autoplay'] );
		$this->add_render_attribute( 'carousel-setting', 'data-loop', $settings['loop'] );
		$this->add_render_attribute( 'carousel-setting', 'data-center', $settings['center'] );
		$this->add_render_attribute( 'carousel-setting', 'data-margin', $settings['margin']['size'] );
		$this->add_render_attribute( 'button-attr', 'class', 'categories-button btn btn-primary' );
		$this->add_render_attribute( 'button-attr', 'href', $settings['btn-link']['url'] );

		$this->add_render_attribute( 'text-box', 'class', 'categories-text' );

		$this->add_render_attribute( 'button-attr-view', 'class', 'view_all_button btn btn-primary' );

		$output = '';
		$devide = 1;

		$cat_class = '';
		if($settings['dots'] == "true"){ 
			$cat_class = 'swiper-bul';
		}

		$center_class = '';
		if($settings['center'] == "true"){ 
			$center_class = 'center_class';
		}

		$cat_view = '';
		if($settings['category-Style'] == "category-carousel"){
			$cat_view = 'swiper';
		}else{
			$cat_view ='category-grid';
		}

		$output .='<div class="'.$cat_view.' product-category category-slider '.$settings['product-Style'].' '.$cat_class.' '.$center_class.' " data-id = "product-category" >';
		$output .= '<div ' . $this->get_render_attribute_string( 'text-box' ) . '>';
				$output .= '<div class="wpcategories-content">';
				if($settings['display-tag'] == "yes"){
					$output .= '<div class="categories-tag">'.$settings['tag'].'</div>';
				}
				if($settings['display-button-sub-title'] == "yes"){
					$output .= '<div class="categories-sub-title">'.$settings['sub-title'].'</div>';}
					if($settings['display_section_title'] == "yes"){
					$output .= '<div class="categories-title">'.$settings['title'].'</div>';}
					if($settings['display_section_description'] == "yes"){
					$output .= '<div class="categories-description">'.$settings['section_description'].'</div>';}
					
					if($settings['display-button'] == "yes"){
						$output .= '<div class="button-categories-wrap">';
							$output .= '<a ' . $this->get_render_attribute_string( 'button-attr' ) . '>';
							$output .= $settings['btn-text'];
							$output .= '</a>';
						$output .= '</div>';
					}
					
				$output .= '</div>';
			$output .= '</div>';
		$output .= '<div ' . $this->get_render_attribute_string( 'carousel-setting' ) . ' >';
			if( $settings['taxonomies'] ){
				$total_category = count( $settings['taxonomies'] );
			}

			if( $settings['product-Style'] == "category-style1" ){
				foreach( $settings['taxonomies'] as $taxonomies ){
					$prod_categories = get_terms( 'product_cat', array(
						'include'	=> $taxonomies,
						'orderby'    => 'name',
						'order'      => 'ASC',
						'hide_empty' => true
					));
					foreach( $prod_categories as $prod_cat ) :
						$output .= '<div class="swiper-slide">';

							$cat_thumb_id = get_term_meta( $prod_cat->term_id, 'thumbnail_id', true );
							$shop_catalog_img = wp_get_attachment_image_src( $cat_thumb_id, 'full' );
							$term_link = get_term_link( $prod_cat, 'product_cat' );

							if( ! empty( $shop_catalog_img ) ){
								$cat_image = '<img src="'. $shop_catalog_img[0] .'" alt="'. $prod_cat->name .'">';
							}else{
								$cat_image = '<img src="'. KARIGARI_TH_URL .'/assets/images/woocommerce-placeholder.png" alt="placeholder">';
							}


								$output .= '<a href="'. $term_link .'" class="cat_desc">';
								
									$output .= '<div class="cat_image">';
									$output .= '<div class="cat_image_box">'. $cat_image .'</div>';
									$output .='</div>';
									
									
										$output .= '<div class="wpcat-content">';
											$output .= '<div class="cat_name">'. $prod_cat->name .'</div>';
											// if( $settings['display-counter'] == "yes" ){
												$output .= '<div class="cat_total_product"> '. $prod_cat->count .' Items</div>';
											// }
											// if( $settings['display-description'] == "yes" ){
												$output .='<div class="cat-description">'. $prod_cat->description .'</div>';
											// }
											// if($settings['display-button'] == "yes"){
												// $output .= '<div class="button-cat-wrap">';
												// 	$output .= $settings['btn-text'];
												// $output .= '</div>';
											// }
										$output .= '</div>';

								$output .= '</a>';

						$output .= '</div>';
					endforeach;
					wp_reset_query();
				}
			}
			
			if( $settings['product-Style'] == "category-style2" ){
				foreach( $settings['taxonomies'] as $taxonomies ){
					$prod_categories = get_terms( 'product_cat', array(
						'include'	=> $taxonomies,
						'orderby'    => 'name',
						'order'      => 'ASC',
						'hide_empty' => true
					));
					foreach( $prod_categories as $prod_cat ) :
						$output .= '<div class="swiper-slide">';

							$cat_thumb_id = get_term_meta( $prod_cat->term_id, 'thumbnail_id', true );
							$shop_catalog_img = wp_get_attachment_image_src( $cat_thumb_id, 'full' );
							$term_link = get_term_link( $prod_cat, 'product_cat' );

							if( ! empty( $shop_catalog_img ) ){
								$cat_image = '<img src="'. $shop_catalog_img[0] .'" alt="'. $prod_cat->name .'">';
							}else{
								$cat_image = '<img src="'. KARIGARI_TH_URL .'/assets/images/woocommerce-placeholder.png" alt="placeholder">';
							}

							$output .= '<div class="cat_group">';
								$output .= '<a href="'. $term_link .'" class="cat_desc">';
								$output .= '<div class="cat_image">' .$cat_image .'</div>';
								$output .= '</a>';
								
									if($settings['display-button-view'] == "yes") { 
										$output .=  '<div class="cat_button">';
										$output .= '<a href="'. $term_link .'"'. $this->get_render_attribute_string( 'button-attr-view' ).' > ';
										$output .=  $settings['btn-text-view'];
										$output .= '</a>';
										$output .= '</div>';
									 } 
									 $output .= '</div>';
										$output .= '<div class="wpcat-content">';
											$output .= '<div class="cat_name"><a href="'. $term_link .'">'. $prod_cat->name .'</a></div>';
												$output .= '<div class="cat_total_product"> '. $prod_cat->count .' Items </div>';
											
												$output .='<div class="cat-description">'. $prod_cat->description .'</div>';
										$output .= '</div>';

								// $output .= '</a>';





								$output .='</div>';
					endforeach;
					wp_reset_query();
				}
			}
			if( $settings['product-Style'] == "category-style3" ){
				foreach( $settings['taxonomies'] as $taxonomies ){
					$prod_categories = get_terms( 'product_cat', array(
						'include'	=> $taxonomies,
						'orderby'    => 'name',
						'order'      => 'ASC',
						'hide_empty' => true
					));
					foreach( $prod_categories as $prod_cat ) :
						$output .= '<div class="swiper-slide">';

							$cat_thumb_id = get_term_meta( $prod_cat->term_id, 'thumbnail_id', true );
							$shop_catalog_img = wp_get_attachment_image_src( $cat_thumb_id, 'full' );
							$term_link = get_term_link( $prod_cat, 'product_cat' );

							if( ! empty( $shop_catalog_img ) ){
								$cat_image = '<img src="'. $shop_catalog_img[0] .'" alt="'. $prod_cat->name .'">';
							}else{
								$cat_image = '<img src="'. KARIGARI_TH_URL .'/assets/images/woocommerce-placeholder.png" alt="placeholder">';
							}


								$output .= '<a href="'. $term_link .'" class="cat_desc">';
								
								
									$output .= '<div class="cat_image">'. $cat_image .'</div>';
									$output .= '</a>';
									$prod_subcategories = get_terms( 'product_cat', array(
										'child_of' => $taxonomies,
									));
									
										$output .= '<div class="wpcat-content">';
								
											$output .= '<div class="cat_name">'. $prod_cat->name .'</div>';
												$output .='<div class="cat-description">'. $prod_cat->description .'</div>';
												$output .= '<div class="cat_total_product"> '. $prod_cat->count .' Items </div>';
												$output .= '<a href="'. $term_link .'"class="cat_icon btn btn-primary">';
												$output .= '<i class="fa-solid fa-arrow-right"></i>';
												$output .= '</a>';
										$output .= '</div>';
				
								$output .='</div>';
					endforeach;
					wp_reset_query();
				}
			}
			if( $settings['product-Style'] == "category-style4" ){
				foreach( $settings['taxonomies'] as $taxonomies ){
					$prod_categories = get_terms( 'product_cat', array(
						'include'	=> $taxonomies,
						'orderby'    => 'name',
						'order'      => 'ASC',
						'hide_empty' => true
					));
					foreach( $prod_categories as $prod_cat ) :
						$output .= '<div class="swiper-slide">';

							$cat_thumb_id = get_term_meta( $prod_cat->term_id, 'thumbnail_id', true );
							$shop_catalog_img = wp_get_attachment_image_src( $cat_thumb_id, 'full' );
							$term_link = get_term_link( $prod_cat, 'product_cat' );

							if( ! empty( $shop_catalog_img ) ){
								$cat_image = '<img src="'. $shop_catalog_img[0] .'" alt="'. $prod_cat->name .'">';
							}else{
								$cat_image = '<img src="'. KARIGARI_TH_URL .'/assets/images/woocommerce-placeholder.png" alt="placeholder">';
							}
									$output .= '<div class="cat_group">';
								$output .= '<a href="'. $term_link .'" class="cat_desc">';
								$output .= '<div class="cat_image">' .$cat_image .'</div>';
								$output .= '</a>';
								
									if($settings['display-button-view'] == "yes") { 
										$output .=  '<div class="cat_button">';
										$output .= '<a href="'. $term_link .'"'. $this->get_render_attribute_string( 'button-attr-view' ).' > ';
										$output .=  $settings['btn-text-view'];
										$output .= '</a>';
										$output .= '</div>';
									 } 
									 $output .= '</div>';
										$output .= '<div class="wpcat-content">';
											$output .= '<div class="cat_name"><a href="'. $term_link .'">'. $prod_cat->name .'</a></div>';
											
												$output .= '<div class="cat_total_product"> '. $prod_cat->count .' Items </div>';
											
												$output .='<div class="cat-description">'. $prod_cat->description .'</div>';
										$output .= '</div>';
								$output .='</div>';
					endforeach;
					wp_reset_query();
				}
			}
		$output .= '</div>';

		if($settings['dots'] == "true" && $settings['category-Style'] == "category-carousel"){
			$output .= '<div class="swiper-pagination"></div>';
		}

		if($settings['arrow'] == "true" && $settings['category-Style'] == "category-carousel"){
			$output .= '<div class="swiper-navigation">';
				$output .= '<div class="swiper-button swiper-button-prev"><svg xmlns="http://www.w3.org/2000/svg" width="36" height="36" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round" class="feather feather-chevron-left"><polyline points="15 18 9 12 15 6"></polyline></svg></div>';
				$output .= '<div class="swiper-button swiper-button-next"><svg xmlns="http://www.w3.org/2000/svg" width="36" height="36" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round" class="feather feather-chevron-right"><polyline points="9 18 15 12 9 6"></polyline></svg></div>';
			$output .= '</div>';
		}

	$output .= '</div>';

			
		echo $output; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped

		if ( Plugin::$instance->editor->is_edit_mode() ) :
			?>
			<script>
				if( jQuery('div').hasClass('product-category') ){
					
					$this = jQuery('.swiper.product-category');
					
					var direction = $this.find( '.swiper-wrapper' ).data('direction');
					var desktop = $this.find( '.swiper-wrapper' ).data('desk');
					var laptop = $this.find( '.swiper-wrapper' ).data('laptop');
					var tablet = $this.find( '.swiper-wrapper' ).data('tablet');
					var mobile = $this.find( '.swiper-wrapper' ).data('mobile');
					var autoplay = $this.find( '.swiper-wrapper' ).data('autoplay');
					var loop = $this.find( '.swiper-wrapper' ).data('loop');
					var center = $this.find( '.swiper-wrapper' ).data('center');
// 					var speed = $this.find( '.swiper-wrapper' ).data('speed');
					var margin = $this.find( '.swiper-wrapper' ).data('margin');

					var next = '.' + jQuery(this).attr("data-id") + ' ' + ".swiper-button-next";
					var prev = '.' + jQuery(this).attr("data-id") + ' ' + ".swiper-button-prev";
					var pagination = '.' + jQuery(this).attr("data-id") + ' ' + ".swiper-pagination";
					
					mySwiper = new Swiper('.swiper.product-category', {
						direction: direction,
						spaceBetween: margin,
						loop: loop,
						centeredSlides: center,
						autoplay: autoplay,
						mousewheel: true,

						breakpoints: {
							0: {
								slidesPerView: 2,
								spaceBetween: 15,
							},
							// breakpoint from 480 up
							480: {
								slidesPerView: mobile,
							},
							// breakpoint from 576 up
							768: {
								slidesPerView: tablet,
							},
							// breakpoint from 1200 up
							1200: {
								slidesPerView: laptop,
							},
							// breakpoint from 1400 up
							1401: {
								slidesPerView: desktop,
								spaceBetween: 30,
							}
						},
						pagination: {
							el: pagination,
							clickable: true,
								type: "progressbar",
						},
						navigation: {
							nextEl: next,
							prevEl: prev,
						},
					});
					
				}
			</script>
			<?php
		endif;
	}
}
Plugin::instance()->widgets_manager->register_widget_type( new \Elementor\Widget_karigari_Categories() );
