<?php
/**
 * Widget API: Elementer Trending Product Widget
 *
 * @package karigari
 * @subpackage Widgets
 * @since 1.0.0
 */

namespace Elementor;
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Elementor Trending Product widget.
 * Elementor widget that displays a Trending Product with the ability to control every
 * aspect of the Trending Product design.
 * @since 1.0.0
 */
class Widget_Trending_Product extends Widget_Base {
	/**
	 * Get widget name.
	 * Retrieve Trending Product widget name.
	 * @since 1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return esc_html__( 'karigari Trending Product', 'karigari' );
	}

	/**
	 * Get widget title.
	 * Retrieve Trending Product widget title.
	 * @since 1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'karigari Trending Product', 'karigari' );
	}

	/**
	 * Get widget icon.
	 * Retrieve Trending Product widget icon.
	 * @since 1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_categories() {
		return array( 'karigari' );
	}

	/**
	 * Get widget icon.
	 * Retrieve heading widget icon.
	 * @since 1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-image';
	}

	/**
	 * Register Trending Product widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @since 1.0.0
	 * @access protected
	 */
	// @codingStandardsIgnoreStart
	protected function register_controls() {
		// @codingStandardsIgnoreEnd
		$this->start_controls_section(
			'Trending Product',
			array(
				'label' => esc_html__( 'Trending Product', 'karigari' ),
			)
		);

		$this->add_control(
			'style',
			array(
				'label'   => esc_html__( 'Select Product Style', 'karigari' ),
				'type'    => Controls_Manager::SELECT,
				'options' => array(
					'product-layout-default' => esc_html__( 'Default', 'karigari' ),
				),
				'default' => 'product-layout-default',
			)
		);
		$this->add_control(
			'owl-style',
			array(
				'label'   => esc_html__( 'Carousel Style', 'karigari' ),
				'type'    => Controls_Manager::SELECT,
				'options' => array(
					'home-default' => esc_html__( 'Row 1', 'karigari' ),
					'home-morden' => esc_html__( 'Row 2', 'karigari' ),
				),
				'default' => 'home-default',
			)
		);

		$this->add_control(
			'product-tab',
			array(
				'label'   => esc_html__( 'Product Tab', 'karigari' ),
				'type'    => Controls_Manager::SELECT,
				'options' => array(
					'tab-true' => esc_html__( 'True', 'karigari' ),
					'tab-false' => esc_html__( 'False', 'karigari' ),
				),
				'default' => 'tab-true',
			)
		);


		$this->add_control(
			'trending-title',
			array(
				'label'       => esc_html__( 'Title', 'karigari' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'label_block' => true,
				'default' => esc_html__( 'Trending Products', 'karigari' ),
			)
		);

	$this->add_control(
			'description',
			array(
				'label'   => esc_html__( 'Description', 'karigari' ),
				'type'    => \Elementor\Controls_Manager::TEXTAREA,
				'default' => esc_html__( 'Description', 'karigari' ),
			)
		);
$this->add_control(
	'display-tag-text',
	array(
		'label'     => esc_html__( 'Use Text ', 'karigari' ),
		'type'      => Controls_Manager::SWITCHER,
		'default'   => 'no',
		'yes'       => esc_html__( 'yes', 'karigari' ),
		'no'        => esc_html__( 'no', 'karigari' ),
	)
);

$this->add_control(
	'tag-text',
	array(
		'label'       => esc_html__( 'Tag Text', 'karigari' ),
		'type'        => Controls_Manager::TEXT,
		'dynamic'     => array(
			'active' => true,
		),
		'condition'   => array(
			'display-tag-text' => 'yes',
		),
		'label_block' => true,
		'default'     => 'Big Sale',
	)
);

$this->add_control(
	'display-upper-title',
	array(
		'label'   => esc_html__( 'Display Upper Title', 'karigari' ),
		'type'    => Controls_Manager::SWITCHER,
		'default' => 'no',
		'yes'     => esc_html__( 'yes', 'karigari' ),
		'no'      => esc_html__( 'no', 'karigari' ),
	)
);

$this->add_control(
	'upper-title',
	array(
		'label'       => esc_html__( 'Upper Title', 'karigari' ),
		'type'        => Controls_Manager::TEXTAREA,
		'dynamic'     => array(
			'active' => true,
		),
		'condition'   => array(
			'display-upper-title' => 'yes',
		),
		'placeholder' => esc_html__( 'Enter your title', 'karigari' ),
		'default'     => esc_html__( 'Add Your Heading Text Here', 'karigari' ),
	)
);

$this->add_control(
	'display-button',
	array(
		'label'     => esc_html__( 'Use Button', 'karigari' ),
		'type'      => Controls_Manager::SWITCHER,
		'default'   => 'no',
		'yes'       => esc_html__( 'yes', 'karigari' ),
		'no'        => esc_html__( 'no', 'karigari' ),
	)
);

$this->add_control(
	'btn-text',
	array(
		'label'       => esc_html__( 'Button Text', 'karigari' ),
		'type'        => Controls_Manager::TEXT,
		'dynamic'     => array(
			'active' => true,
		),
		'condition'   => array(
			'display-button' => 'yes',
		),
		'label_block' => true,
		'default'     => 'Big Sale',
	)
);

$this->add_control(
	'btn-link',
	array(
		'label'       => esc_html__( 'Button URL', 'karigari' ),
		'type'        => Controls_Manager::URL,
		'dynamic'     => array(
			'active' => true,
		),
		'condition'   => array(
			'display-button' => 'yes',
		),
		'placeholder' => esc_html__( 'https://your-link.com', 'karigari' ),
		'default'     => array(
			'url' => '#',
		),
	)
);
		$this->add_control(
			'select-categories',
			array(
				'label' 	=> esc_html__( 'Select Categories', 'karigari' ),
				'type' 		=>Controls_Manager::SELECT2,
				'multiple' => true,
				'options' => [
					'new-products' => esc_html__( 'New Products', 'karigari' ),
					'top-selling' => esc_html__( 'fgdgde Selling', 'karigari' ),
					'featured'  => esc_html__( 'Featured', 'karigari' ),
					'special' => esc_html__( 'Special', 'karigari' ),
				],
			)
		);

		$this->add_control(
			'product-number',
			array(
				'label'       => esc_html__( 'Products per Page', 'karigari' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'label_block' => true,
				'default'     => '5',
			)
		);

		


		$this->add_control(
			'direction',
			array(
				'label'   => esc_html__( 'Direction', 'karigari' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'ASC',
				'options' => array(
					'horizontal' => esc_html__( 'Horizontal', 'karigari' ),
				),
				'default' 	=> 'horizontal',
			)
		);


		$this->end_controls_section();

		$this->start_controls_section(
			'owl',
			array(
				'label'     => esc_html__( 'Carousel', 'karigari' ),
			)
		);

		$this->add_control(
			'desk-number',
			array(
				'label'       => esc_html__( 'Desktop', 'karigari' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'label_block' => true,
				'default'     => '5',
			)
		);

		$this->add_control(
			'laptop-number',
			array(
				'label'       => esc_html__( 'Laptop', 'karigari' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'label_block' => true,
				'default'     => '4',
			)
		);

		$this->add_control(
			'tablet-number',
			array(
				'label'       => esc_html__( 'Tablet', 'karigari' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'label_block' => true,
				'default'     => '3',
			)
		);

		$this->add_control(
			'mobile-number',
			array(
				'label'       => esc_html__( 'Mobile', 'karigari' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'label_block' => true,
				'default'     => '2',
			)
		);

		$this->add_control(
			'autoplay',
			array(
				'label'     => esc_html__( 'Autoplay', 'karigari' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'true',
				'options'   => array(
					'true'  => esc_html__( 'True', 'karigari' ),
					'false' => esc_html__( 'False', 'karigari' ),
				),
			)
		);

		$this->add_control(
			'loop',
			array(
				'label'     => esc_html__( 'Loop', 'karigari' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'false',
				'options'   => array(
					'true'  => esc_html__( 'True', 'karigari' ),
					'false' => esc_html__( 'False', 'karigari' ),
				),
			)
		);

		$this->add_control(
			'dots',
			array(
				'label'     => esc_html__( 'Dots', 'karigari' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'true',
				'options'   => array(
					'true'  => esc_html__( 'True', 'karigari' ),
					'false' => esc_html__( 'False', 'karigari' ),
				),
			)
		);

		$this->add_control(
			'arrow',
			array(
				'label'     => esc_html__( 'Arrow', 'karigari' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'true',
				'options'   => array(
					'true'  => esc_html__( 'True', 'karigari' ),
					'false' => esc_html__( 'False', 'karigari' ),
				),
			)
		);

		$this->add_control(
			'margin',
			array(
				'label'     => esc_html__( 'Margin', 'karigari' ),
				'type'      => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 30,
					],
				],
				'default'   => array(
					'size' => 15,
				),

			)
		);

		$this->add_control(
			'speed',
			array(
				'label'     => esc_html__( 'Speed', 'karigari' ),
				'type'      => Controls_Manager::TEXT,
				'default'   => '1000',
				
			)
		);

		$this->end_controls_section();
	$this->start_controls_section(
			'title_font',
			array(
				'label' => esc_html__( 'Section Title Font', 'karigari' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'     => 'heading_title_color',
				'label' => esc_html__( 'Section Title Font', 'karigari' ),
				'selector' => '{{WRAPPER}} .title-wrap .product-title .section-heading',
			)
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'     => 'desc_typography',
				'label' => esc_html__( 'Section Desciption Font', 'karigari' ),
				'selector' => '{{WRAPPER}} .product-title p',
			)
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'     => 'title_tag_text_color',
				'label' => esc_html__( 'Section Tag Font', 'karigari' ),
				'selector' => '{{WRAPPER}} .title-wrap .product-title .title-text-tag',
			)
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'     => 'section_sub_title_color',
				'label' => esc_html__( 'Section Sub Title Font', 'karigari' ),
				'selector' => '{{WRAPPER}} .tt-section-sab',
			)
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'     => 'section_tab_color',
				'label' => esc_html__( 'Tab Font', 'karigari' ),
				'selector' => '{{WRAPPER}} .ui-tabs-nav .ui-tabs-tab a',
			)
		);
		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'     => 'desc_typography_1',
				'label' => esc_html__( 'Title Font', 'karigari' ),
				'selector' => '{{WRAPPER}} .product .woocommerce-loop-product__title',
			)
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'     => 'desc_typography_2',
				'label' => esc_html__( 'Price Font', 'karigari' ),
				'selector' => '{{WRAPPER}} .product .price .amount bdi, .product .price ins',
			)
		);
		
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'     => 'desc_typography_3',
				'label' => esc_html__( 'Button Text', 'karigari' ),
				'selector' => '{{WRAPPER}} .product .cart-wrap a',
			)
		);
		

		$this->end_controls_section();
		$this->start_controls_section(
			'Trending Product_style',
			array(
				'label' => esc_html__( 'Trending Product Style', 'karigari' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_control(
			'heading_title_color',
			array(
				'label'     => esc_html__( 'Section Title Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .title-wrap .product-title .section-heading' => 'color: {{VALUE}};',
				),
			)
		);
		$this->add_control(
			'description-color',
			array(
				'label'     => esc_html__( 'Section Description Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .product-title p' => 'color: {{VALUE}};',
				),
			)
		);
		$this->add_control(
			'upper-title-color',
			array(
				'label'     => esc_html__( 'Section Upper Title Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'condition'   => array(
					'display-upper-title' => 'yes',
				),
				'selectors' => array(
					'{{WRAPPER}} .product-title .tt-section-sab' => 'color: {{VALUE}};',
				),
			)
		);
		$this->add_control(
			'Text_tag_color',
			array(
				'label'     => esc_html__( 'Section Tag Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .title-wrap .product-title .title-text-tag ' => 'color: {{VALUE}};',
				),
			)
		);
		$this->add_control(
			'tab_color',
			array(
				'label'     => esc_html__( 'Tab Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .ui-tabs-nav .ui-tabs-tab.ui-state-active a' => 'color: {{VALUE}};',
				),
			)
		);
		$this->add_control(
			'tab_hover_color',
			array(
				'label'     => esc_html__( 'Tab Hover Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .ui-tabs-nav .ui-tabs-tab a:hover' => 'color: {{VALUE}};',
				),
			)
		);
		$this->add_control(
			'tab_before_hover_color',
			array(
				'label'     => esc_html__( 'Tab Before Hover Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .ui-tabs-nav .ui-tabs-tab:hover a::before' => 'background-color: {{VALUE}};',
				),
			)
		);
		
		$this->add_control(
			'tab_before_color',
			array(
				'label'     => esc_html__( 'Tab Before Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .ui-tabs-nav .ui-tabs-tab.ui-state-active a::before' => 'background-color: {{VALUE}};',
				),
			)
		);
		$this->add_control(
			'title_color',
			array(
				'label'     => esc_html__( 'Title Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .product .woocommerce-loop-product__title' => 'color: {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'title_hover_color',
			array(
				'label'     => esc_html__( 'Title Hover Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .product:hover .woocommerce-loop-product__title' => 'color: {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'price_color',
			array(
				'label'     => esc_html__( 'Price Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .product .price .amount bdi, .product .price ins' => 'color: {{VALUE}};',
				),
			)
		);
		$this->add_control(
			'product_hover_color',
			array(
				'label'     => esc_html__( 'Button Hover Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .product .product-button-wrap .btn-hv a::after, section.product .cart-wrap a::after' => 'background-color: {{VALUE}};',
				),
			)
		);
		$this->add_control(
			'sale_color',
			array(
				'label'     => esc_html__( 'Sale Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .karigari-sale span.label ' => 'background-color: {{VALUE}};',
				),
			)
		);
		$this->add_control(
			'rating_color',
			array(
				'label'     => esc_html__( 'Rating Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .product .wrap-rate .star-rating::before ' => 'color: {{VALUE}};',
				),
			)
		);
		$this->add_control(
			'rating__before_color',
			array(
				'label'     => esc_html__( 'Rating before Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .product .star-rating span::before' => 'color: {{VALUE}};',
				),
			)
		);
		
			$this->add_control(
			'add_to_card_after_focus',
			array(
				'label'     => esc_html__( 'Add-to-card After focus', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} section.product .cart-wrap a.loading' =>'background-color: {{VALUE}};',
				),
			)
		);
		
		$this->add_control(
			'viewall_button',
			array(
				'label'     => esc_html__( 'View All Button', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .button-title-wrap .btn-primary::after' =>'background-color: {{VALUE}};',
				),
			)
		);
		$this->add_control(
			'viewall_button_border',
			array(
				'label'     => esc_html__( 'View All Button Border', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .product-trending .button-title-wrap a.title-button:hover' =>'border-color: {{VALUE}};',
				),
			)
		);
		$this->end_controls_section();
	}

	/**
	 * Render Trending Product widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();
		global $wpml, $product;
		
		$paged    = ( get_query_var( 'paged' ) ) ? get_query_var( 'paged' ) : 1;

		/* $this->add_render_attribute(
			'category-carousel',
			[
				'class' => ['swiper product-trending' ]
			]
		); */

		$this->add_render_attribute( 'carousel-setting', 'class', 'swiper-wrapper' );
		$this->add_render_attribute( 'carousel-setting', 'data-direction', $settings['direction'] );
		$this->add_render_attribute( 'carousel-setting', 'data-dots', $settings['dots'] );
		$this->add_render_attribute( 'carousel-setting', 'data-nav', $settings['arrow'] );
		$this->add_render_attribute( 'carousel-setting', 'data-desk', $settings['desk-number'] );
		$this->add_render_attribute( 'carousel-setting', 'data-laptop', $settings['laptop-number'] );
		$this->add_render_attribute( 'carousel-setting', 'data-tablet', $settings['tablet-number'] );
		$this->add_render_attribute( 'carousel-setting', 'data-mobile', $settings['mobile-number'] );
		$this->add_render_attribute( 'carousel-setting', 'data-autoplay', $settings['autoplay'] );
		$this->add_render_attribute( 'carousel-setting', 'data-loop', $settings['loop'] );
		$this->add_render_attribute( 'carousel-setting', 'data-speed', $settings['speed'] );
		$this->add_render_attribute( 'carousel-setting', 'data-margin', $settings['margin']['size'] );
		$this->add_render_attribute( 'button-attr', 'class', 'title-button btn btn-primary' );
		$this->add_render_attribute( 'button-attr', 'href', $settings['btn-link']['url'] );
		$this->add_inline_editing_attributes( 'description', 'basic' );

		$product_per_page = $settings['product-number'];

		$this->add_render_attribute(
			'attribute',
			[
				'class' => ['product-trending' , $settings['style'] , $settings['owl-style'] ]
			]
		);

		$i=1;
		?>
				<div <?php echo $this->get_render_attribute_string( 'attribute' ); ?> id="product-trending">
					<div class="title-wrap">
						<?php if( ! empty( $settings['trending-title'] ) ){ ?>
							<div class="product-title">
							<?php  if($settings['display-tag-text'] == "yes"){?>
						<div class="title-text-tag"><?php echo esc_html( $settings['tag-text']);?></div>
						<?php  }?>
			<?php if ( $settings['display-upper-title'] == 'yes' ) { ?>
			<span class="tt-section-sab"><?php echo sprintf( '%1$s', esc_html( $settings['upper-title'] ) ); ?></span>
			<?php } ?>

								<h2 class="section-heading"><?php echo $settings['trending-title']; ?></h2>			
								
<?php if ( $settings['description'] ) { ?>
						<div class="subtitle-wrap"><p class="title_description"><?php echo html_entity_decode( $settings['description'] ); ?></P></div>
			<?php } ?>

							</div>
						<?php }
						if( !empty( $settings['select-categories'] ) ){
							if($settings['product-tab'] == "tab-true"){ ?>
								<ul>
									<?php foreach( $settings['select-categories'] as $categories ){
										$title = str_replace("-", " ", $categories);
										$c_title = ucwords( $title ); ?>
										<li><a href="#<?php echo $categories; ?>"><?php esc_html_e($c_title, 'karigari'); ?></a></li>
									<?php } ?>
								</ul>
							<?php
							}
						} ?>
					</div>
					<?php 
					if( !empty( $settings['select-categories'] ) ){
						foreach( $settings['select-categories'] as $categories ){
							if( $categories == 'featured' ) { ?>

								<div class="swiper products-trending featured product-swiper" data-id = "featured" id = "featured" >
									<div <?php echo $this->get_render_attribute_string( 'carousel-setting' ); ?> >

										<?php
										$devide = 1;
										$tax_query[] = array(
											'taxonomy' => 'product_visibility',
											'field'    => 'name',
											'terms'    => 'featured',
											'operator' => 'IN', // or 'NOT IN' to exclude feature products
										);
										$featured = array(
											'post_type'           => 'product',
											'post_status'         => 'publish',
											'ignore_sticky_posts' => 1,
											'posts_per_page'      => $product_per_page,
											'orderby'             => 'date',
											'order'               => 'desc',
											'tax_query'           => $tax_query 
										);
										$loop = new \WP_Query($featured);
										$count = $loop->found_posts;

										if ( $loop->have_posts() ) {
											while ( $loop->have_posts() ) : $loop->the_post();

												echo '<div class="swiper-slide">';

													if( $count >= 10 && $settings['owl-style'] == "home-morden"){
														if( $devide%2 != 0 ){
															echo '<div class="item">';
														}
															if( $settings['style'] == "product-layout-default" ){
																wc_get_template_part( 'content', 'product' );
									
															}
														if( $devide%2 == 0 ){
															echo '</div>';
															$devide = 0;
														}
													} else {
														if( $settings['style'] == "product-layout-default" ){
															wc_get_template_part( 'content', 'product' );
														
														}
													}

												echo '</div>';
							
											$devide++;
											endwhile;
											if( $devide%2 == 0 &&  $count >= 10 && $settings['owl-style'] == "home-morden"){
												echo '</div>';
											}
										} else {
											echo esc_html__( 'No products found' );
										}
										wp_reset_postdata();
										?>
									</div>
									<?php
										if( $settings['dots'] == "true"){
									?>
										<div class="swiper-pagination"></div>
									<?php
										}
									?>

									<?php
										if( $settings['arrow'] == "true"){
									?>
										<div class="swiper-navigation">
											<div class="swiper-button swiper-button-prev"><svg xmlns="http://www.w3.org/2000/svg" width="20" height="20" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round" class="feather feather-chevron-left"><polyline points="15 18 9 12 15 6"></polyline></svg></div>
											<div class="swiper-button swiper-button-next"><svg xmlns="http://www.w3.org/2000/svg" width="20" height="20" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round" class="feather feather-chevron-right"><polyline points="9 18 15 12 9 6"></polyline></svg></div>
										</div>
									<?php
										}
									?>
								</div><!-- #featured -->
							<?php }elseif( $categories == 'new-products' ){ ?>

								<div class="swiper products-trending new-products product-swiper" data-id = "new-products" id = "new-products" >
									<div <?php echo $this->get_render_attribute_string( 'carousel-setting' ); ?> >

										<?php
										$devide = 1;		
										$new_products = array(
											'post_type' 	 => 'product',
											'posts_per_page' => $product_per_page,
											'orderby'        => 'date',
											'order'  		 => 'desc',
										);
										$loop = new \WP_Query($new_products);
										$count = $loop->found_posts;

										if ( $loop->have_posts() ) {
											while ( $loop->have_posts() ) : $loop->the_post();
												echo '<div class="swiper-slide">';
													if( $count >= 8 && $settings['owl-style'] == "home-morden"){
									
														if( $devide%2 != 0 ){
															echo '<div class="item">';
														}
															if( $settings['style'] == "product-layout-default" ){
																wc_get_template_part( 'content', 'product' );
															
															}
									
															/* echo '<span>'.$devide.'</span>'; */
									
														if( $devide%2 == 0 ){
															echo '</div>';
															$devide = 0;
														}
									
													} else {
														if ( class_exists( 'WooCommerce' ) ) {
															if( $settings['style'] == "product-layout-default" ){
																wc_get_template_part( 'content', 'product' );
														
															
															}
														}
													}
												echo '</div>';
											$devide++;
											endwhile;
											if( $devide%2 == 0 &&  $count >= 8 && $settings['owl-style'] == "home-morden"){
												echo '</div>';
											}
										} else {
											echo esc_html__( 'No products found' );
										}
										wp_reset_postdata();
										?>
									
									</div>
									<?php
										if( $settings['dots'] == "true"){
									?>
										<div class="swiper-pagination"></div>
									<?php
										}
									?>

									<?php
										if( $settings['arrow'] == "true"){
									?>
										<div class="swiper-navigation">
											<div class="swiper-button swiper-button-prev"><svg xmlns="http://www.w3.org/2000/svg" width="20" height="20" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round" class="feather feather-chevron-left"><polyline points="15 18 9 12 15 6"></polyline></svg></div>
											<div class="swiper-button swiper-button-next"><svg xmlns="http://www.w3.org/2000/svg" width="20" height="20" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round" class="feather feather-chevron-right"><polyline points="9 18 15 12 9 6"></polyline></svg></div>
										</div>
									<?php
										}
									?>
								</div><!-- #new-products -->
							<?php }elseif( $categories == 'top-selling' ){ ?>

								<div class="swiper products-trending top-selling product-swiper" data-id = "top-selling" id = "top-selling" >
									<div <?php echo $this->get_render_attribute_string( 'carousel-setting' ); ?> >

										<?php
										$devide = 1;		
										$top_sell = array(
											'post_type' 		=> 'product',
											'meta_key'  		=> 'total_sales',
											'orderby'   		=> 'meta_value_num',
											'order' 			=> 'desc',
											'posts_per_page'	=> $product_per_page
										);
										$loop = new \WP_Query($top_sell);
										$count = $loop->found_posts;

										if ( $loop->have_posts() ) {
											while ( $loop->have_posts() ) : $loop->the_post();
												echo '<div class="swiper-slide">';
													if( $count >= 8 && $settings['owl-style'] == "home-morden"){
									
														if( $devide%2 != 0 ){
															echo '<div class="item">';
														}
															if( $settings['style'] == "product-layout-default" ){
																wc_get_template_part( 'content', 'product' );
															
															}
															/* echo '<span>'.$devide.'</span>'; */
									
														if( $devide%2 == 0 ){
															echo '</div>';
															$devide = 0;
														}
									
													} else {
														if( $settings['style'] == "product-layout-default" ){
															wc_get_template_part( 'content', 'product' );
														
														}
													}
												echo '</div>';
											$devide++;
											endwhile;
											if( $devide%2 == 0 &&  $count >= 8 && $settings['owl-style'] == "home-morden"){
												echo '</div>';
											}
										} else {
											echo esc_html__( 'No products found' );
										}
										wp_reset_postdata();
										?>
									
									</div>
									<?php
										if( $settings['dots'] == "true"){
									?>
										<div class="swiper-pagination"></div>
									<?php
										}
									?>

									<?php
										if( $settings['arrow'] == "true"){
									?>
										<div class="swiper-navigation">
											<div class="swiper-button swiper-button-prev"><svg xmlns="http://www.w3.org/2000/svg" width="20" height="20" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round" class="feather feather-chevron-left"><polyline points="15 18 9 12 15 6"></polyline></svg></div>
											<div class="swiper-button swiper-button-next"><svg xmlns="http://www.w3.org/2000/svg" width="20" height="20" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round" class="feather feather-chevron-right"><polyline points="9 18 15 12 9 6"></polyline></svg></div>
										</div>
									<?php
										}
									?>
								</div><!-- #top-selling -->
							<?php }elseif( $categories == 'special' ){ ?>

									<div class="swiper products-trending special product-swiper" data-id = "special" id = "special" >
									<div <?php echo $this->get_render_attribute_string( 'carousel-setting' ); ?> >

										<?php	
										$devide = 1;	
										$top_sell = array(
											'post_type' 		=> 'product',
											'posts_per_page'	=> $product_per_page,
											'meta_query'     => array(
												'relation' => 'OR',
												array( // Simple products type
													'key'           => '_sale_price',
													'value'         => 0,
													'compare'       => '>',
													'type'          => 'numeric'
												),
												array( // Variable products type
													'key'           => '_min_variation_sale_price',
													'value'         => 0,
													'compare'       => '>',
													'type'          => 'numeric'
												)
											)
										);
										$loop = new \WP_Query($top_sell);
										$count = $loop->found_posts;
										
										if ( $loop->have_posts() ) {
											while ( $loop->have_posts() ) : $loop->the_post();
												
												echo '<div class="swiper-slide">';
													if( $count >= 8 && $settings['owl-style'] == "home-morden"){
									
														if( $devide%2 != 0 ){
															echo '<div class="item">';
														}
															if( $settings['style'] == "product-layout-default" ){
																wc_get_template_part( 'content', 'product' );
															
															}
															/* echo '<span>'.$devide.'</span>'; */
									
														if( $devide%2 == 0 ){
															echo '</div>';
															$devide = 0;
														}
									
													} else {
														
														if( $settings['style'] == "product-layout-default" ){
															wc_get_template_part( 'content', 'product' );
														
														}
									
													}
												echo '</div>';
							
											$devide++;
											endwhile;
											if( $devide%2 == 0 &&  $count >= 10 && $settings['owl-style'] == "home-morden"){
												echo '</div>';
											}
										} else {
											echo esc_html__( 'No products found' );
										}
										wp_reset_postdata();
										?>
									
									</div>
										<?php
										if( $settings['dots'] == "true"){
									?>
										<div class="swiper-pagination"></div>
									<?php
										}
									?>

									<?php
										if( $settings['arrow'] == "true"){
									?>
										<div class="swiper-navigation">
											<div class="swiper-button swiper-button-prev"><svg xmlns="http://www.w3.org/2000/svg" width="20" height="20" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round" class="feather feather-chevron-left"><polyline points="15 18 9 12 15 6"></polyline></svg></div>
											<div class="swiper-button swiper-button-next"><svg xmlns="http://www.w3.org/2000/svg" width="20" height="20" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round" class="feather feather-chevron-right"><polyline points="9 18 15 12 9 6"></polyline></svg></div>
										</div>
									<?php
										}
									?>
								</div> <!-- #special -->
								
							<?php }
						} 
					} ?>
					<?php if($settings['display-button'] == "yes") { ?>
				<div class="button-title-wrap">
				<a <?php echo $this->get_render_attribute_string( 'button-attr' ) ?>> 
				<?php echo html_entity_decode ($settings['btn-text']);?>
			</a>
				</div>
				</div>
				
			<?php } ?>
		<!-- echo $output; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped -->
		<?php
		if ( Plugin::$instance->editor->is_edit_mode() ) :
			?>
			<script>
				if( jQuery('div').hasClass('products-trending') ){

						$this = jQuery('.swiper.products-trending');

						var direction = $this.find( '.swiper-wrapper' ).data('direction');
						var desktop = $this.find( '.swiper-wrapper' ).data('desk');
						var laptop = $this.find( '.swiper-wrapper' ).data('laptop');
						var tablet = $this.find( '.swiper-wrapper' ).data('tablet');
						var mobile = $this.find( '.swiper-wrapper' ).data('mobile');
						var autoplay = $this.find( '.swiper-wrapper' ).data('autoplay');
						var loop = $this.find( '.swiper-wrapper' ).data('loop');
						var speed = $this.find( '.swiper-wrapper' ).data('speed');
						var margin = $this.find( '.swiper-wrapper' ).data('margin');

						var next = '.'+jQuery(this).attr("data-id")+' '+'+'+".swiper-navigation .swiper-button-next";
						var prev = '.'+jQuery(this).attr("data-id")+' '+'+'+".swiper-navigation .swiper-button-prev";
						var pagination = '.'+jQuery(this).attr("data-id")+' '+'+'+".swiper-pagination";
						mySwiper = new Swiper('.swiper.products-trending', {
							direction: direction,
							spaceBetween: margin,
							loop: loop,
							autoplay: autoplay,
							speed : speed,
							breakpoints: {
								0: {
									items: 	1
								},
								// breakpoint from 480 up
								480: {
									slidesPerView: 2,
								},
								// breakpoint from 576 up
								768: {
									slidesPerView: mobile,
								},
								// breakpoint from 992 up
								992: {
									slidesPerView: tablet,
								},
								// breakpoint from 1200 up
								1200: {
									slidesPerView: laptop,
								},
								// breakpoint from 1400 up
								1401: {
									slidesPerView: desktop,
								}
							},
							pagination: {
							el: pagination,
							clickable: true,
							type: "progressbar",
						},
						navigation: {
							nextEl: next,
							prevEl: prev,
						},
						});
					jQuery( "#product-trending" ).tabs();
				}
			</script>
			<?php
		endif;
	}
}
Plugin::instance()->widgets_manager->register_widget_type( new \Elementor\Widget_Trending_Product() );
