<?php
/**
 * Timer Shortcode
 *
 * @package karigari
 */

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
/**
 * Elementor Timer widget.
 *
 * Elementor widget that displays a Timer with the ability to control every
 * aspect of the Timer design.
 *
 * @since 1.0.0
 */
class Widget_Timer extends Widget_Base {
	/**
	 * Get widget name.
	 *
	 * Retrieve Timer widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return esc_html__( 'Timer', 'karigari' );
	}
	/**
	 * Get widget title.
	 *
	 * Retrieve Timer widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Timer', 'karigari' );
	}
	/**
	 * Get widget icon.
	 *
	 * Retrieve Timer widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_categories() {
		return array( 'karigari' );
	}
	/**
	 * Get widget icon.
	 *
	 * Retrieve heading widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */

	public function get_icon() {
		return 'eicon-tabs';
	}

	/**
	 * Register Timer widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'timer',
			array(
				'label' => esc_html__( 'Timer', 'karigari' ),
			)
		);
		$this->add_control(
			'tab_heading',
			array(
				'label'   => esc_html__( 'Title', 'plugin-name' ),
				'type'    => Controls_Manager::TEXTAREA,
				'default' => esc_html__( 'Title', 'plugin-name' ),
			)
		);
		$this->add_control(
			'date_time',
			array(
				'label'       => esc_html__( 'Date & Time', 'karigari' ),
				'type'        => Controls_Manager::DATE_TIME,
				'label_block' => true,
			)
		);	
		$this->add_control(
			'display-upper-title',
			array(
				'label'   => esc_html__( 'Display Upper Title', 'karigari' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'no',
				'yes'     => esc_html__( 'yes', 'karigari' ),
				'no'      => esc_html__( 'no', 'karigari' ),
			)
		);

		
		$this->add_control(
			'upper-title',
			array(
				'label'       => esc_html__( 'Upper Title', 'karigari' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => array(
					'active' => true,
				),
				'condition'   => array(
					'display-upper-title' => 'yes',
				),
				'placeholder' => esc_html__( 'Enter your title', 'karigari' ),
				'default'     => esc_html__( 'Add Your Heading Text Here', 'karigari' ),
			)
		);

		$this->add_control(
			'tab_content',
			array(
				'label'      => esc_html__( 'Description', 'karigari' ),
				'type'       => Controls_Manager::TEXTAREA,
				'show_label' => false,
			)
		);
		$this->add_control(
			'button-text',
			array(
				'label'       => esc_html__( 'Button Text', 'karigari' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'label_block' => true,
				'default'     => esc_html__( 'Button', 'karigari' ),
			)
		);

		$this->add_control(
			'button-link',
			array(
				'label'   => esc_html__( 'Link', 'karigari' ),
				'type'    => Controls_Manager::URL,
				'dynamic' => array(
					'active' => true,
				),
				'default' => array(
					'url' => '#',
				),
			)
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'text_font',
			array(
				'label' => esc_html__( 'Text Font', 'karigari' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'     => 'content_typography',
				'label' => esc_html__( 'Timer Text Font', 'karigari' ),
				'selector' => '{{WRAPPER}} .banner-timer .timer-head',
			)
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'     => 'timer_content_typography_01',
				'label' => esc_html__( 'Timer Font', 'karigari' ),
				'selector' => '{{WRAPPER}} .banner-timer .timer-date>div .text',
			)
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'     => 'timer_content_typography_02',
				'label' => esc_html__( 'Title Font', 'karigari' ),
				'selector' => '{{WRAPPER}} .banner-timer .timer-date div p',
			)
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'     => 'timer_content_typography_03',
				'label' => esc_html__( 'Timer content Font', 'karigari' ),
				'selector' => '{{WRAPPER}} .banner-timer .timer-content',
			)
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'     => 'timer_content_typography_04',
				'label' => esc_html__( 'Timer Button Font', 'karigari' ),
				'selector' => '{{WRAPPER}} .page .banner-timer .timer-button',
			)
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'timer-style',
			array(
				'label' => esc_html__( 'Style', 'karigari' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_control(
			'title_color',
			array(
				'label'     => esc_html__( 'Title Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .banner-timer .timer-head' => 'color: {{VALUE}};',
				), 
			)
		);

		$this->add_control(
			'timer_color',
			array(
				'label'     => esc_html__( 'Timer Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .banner-timer .timer-date div p' => 'color: {{VALUE}};',
				), 
			)
		);

		$this->add_control(
			'timer_color_text',
			array(
				'label'     => esc_html__( 'Timer Text Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .banner-timer .timer-date > div .text' => 'color: {{VALUE}};',
				), 
			)
		);
		$this->add_control(
			'timer_color_text_after',
			array(
				'label'     => esc_html__( 'Timer Text Color After', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .banner-timer .timer-date > div::after, .banner-timer .timer-date > div::after' => 'color: {{VALUE}};',
				), 
			)
		);
	
		$this->add_control(
			'upper-title-color',
			array(
				'label'     => esc_html__( 'Upper Title Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'condition'   => array(
					'display-upper-title' => 'yes',
				),
				'selectors' => array(
					'{{WRAPPER}} .banner-timer .tt-section-sab' => 'color: {{VALUE}};',
				),
			)
		);
		$this->add_control(
			'deciption_color',
			array(
				'label'     => esc_html__( 'Desciption Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .banner-timer .timer-content' => 'color: {{VALUE}};',
				), 
			)
		);

		$this->add_control(
			'button_color',
			array(
				'label'     => esc_html__( 'Button Text Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .banner-timer .timer-button' => 'color: {{VALUE}};',
				), 
			)
		);

		$this->add_control(
			'button_bg_color',
			array(
				'label'     => esc_html__( 'Button Background Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .banner-timer .timer-button' => 'background: {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'button_title_hv__color',
			array(
				'label'     => esc_html__( 'Button Title Hover Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .banner-timer .timer-button:hover' => 'color: {{VALUE}};',
				), 
			)
		);
		
		
		$this->add_control(
			'button_bg_hv_color',
			array(
				'label'     => esc_html__( 'Button Background Hover Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .banner-timer .timer-button:hover, .btn-primary::after' => 'background: {{VALUE}};',
				),
			)
		);

		$this->end_controls_section();
	}
	/**
	 * Render Timer widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();
		$tabs     = $this->get_settings_for_display( 'tabs' );

		$tab_heading = $settings['tab_heading'] ? $settings['tab_heading'] : '';
		$date_time 	 = $settings['date_time'] ? $settings['date_time'] : '';
		$tab_content = $settings['tab_content'] ? $settings['tab_content'] : '';
		$button_text = $settings['button-text'] ? $settings['button-text'] : '';

		$this->add_render_attribute( 'button-attribute', 'class', 'timer-button btn btn-primary' );
		$this->add_render_attribute( 'button-attribute', 'href', $settings['button-link']['url'] );
		$settings['button-link']['is_external'] ? $this->add_render_attribute( 'button-attribute', 'target', '_blank' ):'';

		?>
		<div class="banner-timer">
		<?php if ( $settings['display-upper-title'] == 'yes' ) { ?>
			<span class="tt-section-sab"><?php echo sprintf( '%1$s', esc_html( $settings['upper-title'] ) ); ?></span>
			<?php } ?>
			<?php if( ! empty( $tab_heading ) ){ ?><div class="timer-head"><?php echo $tab_heading; ?></div><?php } ?>
			<?php if( ! empty( $date_time ) ){ ?><div class="timer-date" id="timer-date" data="<?php echo $date_time; ?>">
				<div>
					<p id="days" class="days"><div class="text">Days</div></p>
				</div>
				<div>
					<p id="hours" class="hours"><div class="text">Hours</div></p>
				</div>
				<div>
					<p id="minutes" class="minutes"><div class="text">Mins</div></p>
				</div>
				<div>
					<p id="second" class="second"><div class="text">Secs</div></p>
				</div>
			</div><?php } ?>
			<?php if( ! empty( $tab_content ) ){ ?><div class="timer-content"><?php echo $tab_content; ?></div><?php } ?>
			<?php if( ! empty( $button_text ) ){ ?><a <?php echo $this->get_render_attribute_string( 'button-attribute' ); ?> ><?php echo $button_text; ?></a><?php } ?>
		</div>
		<?php
	}
}
Plugin::instance()->widgets_manager->register_widget_type( new \Elementor\Widget_Timer() );
