<?php
/**
 * Widget API: Elementer Video Widget
 * @package karigari
 */

namespace Elementor;
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Elementor Video widget.
 * Elementor widget that displays a Video with the ability to control every
 * aspect of the Video design.
 * @since 1.0.0
 */
class Widget_Video_Popup extends Widget_Base {
	/**
	 * Get widget name.
	 * Retrieve Video widget name.
	 * @since 1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return esc_html__( 'Video Popup', 'karigari' );
	}

	/**
	 * Get widget title.
	 * Retrieve Video Popup widget title.
	 * @since 1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Video', 'karigari' );
	}

	/**
	 * Get widget icon.
	 * Retrieve Video widget icon.
	 * @since 1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_categories() {
		return array( 'karigari' );
	}

	/**
	 * Get widget icon.
	 * Retrieve heading widget icon.
	 * @since 1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-image-box';
	}

	/**
	 * Register Video widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 * @since 1.0.0
	 * @access protected
	 */
	// @codingStandardsIgnoreStart
	protected function register_controls() {
		// @codingStandardsIgnoreEnd
		$this->start_controls_section(
			'video',
			array(
				'label' => esc_html__( 'Video Popup', 'karigari' ),
			)
		);

		$this->add_control(
			'video-style',
			array(
				'label'   => esc_html__( 'video Style', 'karigari' ),
				'type'    => Controls_Manager::SELECT,
				'options' => array(
					'video-style-1' => esc_html__( 'Morden Style', 'karigari' ),
					'video-style-2' => esc_html__( 'Classic Style', 'karigari' ),
				),
				'default' => 'video-style-1',
			)
		);

		$this->add_control(
			'video-image',
			array(
				'label'     => esc_html__( 'Choose Image', 'karigari' ),
				'type'      => Controls_Manager::MEDIA,
				'dynamic'   => array(
					'active' => true,
				),
				'default'   => array(
					'url' => Utils::get_placeholder_image_src(),
				),

			)
		);
		
		$this->add_control(
			'video-link',
			array(
			'label'       => esc_html__( 'Video URL', 'karigari' ),
			'type'        => Controls_Manager::URL,
			'dynamic'     => array(
			'active' => true,
			),
			'placeholder' => esc_html__( 'https://your-link.com', 'karigari' ),
			'default'     => array(
			'url' => '#',
			),
			)
			);
	
$this->add_control(
	'select-media',
	array(
	'label'   => esc_html__( 'Icon / Text', 'karigari' ),
	'type'    => Controls_Manager::SELECT,
	'options' => array(
	'icon'  => esc_html__( 'Icon', 'karigari' ),
	'text' => esc_html__( 'Text', 'karigari' ),
	),
	'default' => 'icon',
	)
	);
	$this->add_control(
	'text',
	array(
	'label'   => esc_html__( 'text', 'karigari' ),
	'type'    => \Elementor\Controls_Manager::TEXTAREA,
	'default' => esc_html__( 'text', 'karigari' ),
	'condition' => array(
	'select-media' => 'text',
	),
	)
	);
	$this->add_control(
	'video-icon',
	array(
	'label'            => esc_html__( 'Video-icon', 'hostbridge' ),
	'type'             => Controls_Manager::ICONS,
	'fa4compatibility' => 'icon',
	'condition'        => array(
	'select-media' => 'icon',
	),
	'default'          => array(
	'value' => 'fas fa-thumbs-up',
	),
	)
	);
		$this->add_control(
			'direction',
			array(
				'label'   => esc_html__( 'Direction', 'karigari' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'ASC',
				'options' => array(
					'horizontal' => esc_html__( 'Horizontal', 'karigari' ),
				),
				'default' 	=> 'horizontal',
			)
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'icon-position',
			array(
				'label'   => esc_html__( 'Icon Position', 'karigari' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => array(
					'tt-icon-left'  => array(
						'title' => esc_html__( 'Left', 'karigari' ),
						'icon'  => 'eicon-h-align-left',
					),
					'tt-icon-top'   => array(
						'title' => esc_html__( 'Top', 'karigari' ),
						'icon'  => 'eicon-v-align-top',
					),
					'tt-icon-right' => array(
						'title' => esc_html__( 'Right', 'karigari' ),
						'icon'  => 'eicon-h-align-right',
					),
					'tt-icon-bottom' => array(
						'title' => esc_html__( 'Bottom', 'karigari' ),
						'icon'  => 'eicon-v-align-bottom',
					),
					'tt-icon-center' => array(
						'title' => esc_html__( 'Center', 'karigari' ),
						'icon'  => 'eicon-h-align-center',
					),
				),

				'default' => 'tt-icon-top',

			)
		);

		$this->add_responsive_control(
			'align',
			array(
				'label'   => esc_html__( 'Alignment', 'karigari' ),
				'type'    => Controls_Manager::CHOOSE,
				'default' => 'text-start',
				'options' => array(
					'text-start'   => array(
						'title' => esc_html__( 'Left', 'karigari' ),
						'icon'  => 'eicon-text-align-left',
					),
					'text-center' => array(
						'title' => esc_html__( 'Center', 'karigari' ),
						'icon'  => 'eicon-text-align-center',
					),
					'text-end'  => array(
						'title' => esc_html__( 'Right', 'karigari' ),
						'icon'  => 'eicon-text-align-right',
					),
				),

			)
		);

		
		$this->end_controls_section();


		$this->start_controls_section(
			'owl',
			array(
				'label'     => esc_html__( 'Carousel', 'karigari' ),
			)
		);

		$this->add_control(
			'desk',
			array(
				'label'       => esc_html__( 'Desktop', 'karigari' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'label_block' => true,
				'default'     => '5',
			)
		);

		$this->add_control(
			'laptop',
			array(
				'label'       => esc_html__( 'Laptop', 'karigari' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'label_block' => true,
				'default'     => '5',
			)
		);

		$this->add_control(
			'tablet',
			array(
				'label'       => esc_html__( 'Tablet', 'karigari' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'label_block' => true,
				'default'     => '5',
			)
		);

		$this->add_control(
			'mobile',
			array(
				'label'       => esc_html__( 'Mobile', 'karigari' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'label_block' => true,
				'default'     => '5',
			)
		);

		$this->add_control(
			'autoplay-delay',
			array(
				'label'     => esc_html__( 'Autoplay Delay Time', 'karigari' ),
				'type'      => Controls_Manager::TEXT,
				'default'   => '1',
				
			)
		);
		$this->add_control(
			'loop',
			array(
				'label'     => esc_html__( 'Loop', 'karigari' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'true',
				'options'   => array(
					'true'  => esc_html__( 'True', 'karigari' ),
					'false' => esc_html__( 'False', 'karigari' ),
				),
			)
		);

		$this->add_control(
			'margin',
			array(
				'label'     => esc_html__( 'Margin', 'karigari' ),
				'type'      => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 30,
					],
				],
				'default'   => array(
					'size' => 15,
				),

			)
		);
		$this->add_control(
		'speed',
			array(
				'label'     => esc_html__( 'Speed', 'karigari' ),
				'type'      => Controls_Manager::TEXT,
				'default'   => '1500',

			)
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'text_font',
			array(
				'label' => esc_html__( 'Text Font', 'karigari' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'     => 'content_typography',
				'label' => esc_html__( 'Title Font', 'karigari' ),
				'selector' => '{{WRAPPER}} .tt-video .swiper-js-container .swiper-slide, a.youtube-popup p.btn.btn-primary',
			)
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'text-style',
			array(
				'label' => esc_html__( 'Text Color', 'karigari' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_control(
			'title_color',
			array(
				'label'     => esc_html__( 'Text Color', 'karigari' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} .tt-video .swiper-js-container .swiper-slide, a.youtube-popup p.btn.btn-primary' => 'color: {{VALUE}};',
				), 
			)
		);

		$this->end_controls_section();
	}

	/**
	 * Render fancybox widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {

		$settings = $this->get_settings();

		$this->add_render_attribute( 'image', 'src', $settings['video-image']['url'] );
		$this->add_render_attribute( 'image', 'srcset', $settings['video-image']['url'] );
		$this->add_render_attribute( 'image', 'alt', Control_Media::get_image_alt( $settings['video-image'] ) );
		$this->add_render_attribute( 'image', 'title', Control_Media::get_image_title( $settings['video-image'] ) );
		$image_html = Group_Control_Image_Size::get_attachment_image_html( $settings, 'full', 'video-image' );

		$this->add_render_attribute( 'button-attr', 'class', 'youtube-popup' );
		$this->add_render_attribute( 'button-attr', 'href', $settings['video-link']['url'] );

		$this->add_render_attribute( 'video-popup', 'class', 'tt-video' );
		$this->add_render_attribute( 'video-popup', 'class', esc_attr( $settings['align'] ) );

		$this->add_inline_editing_attributes( 'text', 'basic' );

		
		$output = '';
		$output .= '<div ' . $this->get_render_attribute_string( 'video-popup' ) . '>';

			if( $settings['video-style'] == "video-style-1" ){

				$output .= '<div class="swiper-js-container">';
					$output .= '<div class="swiper video swiper-video" data-id="video">';
						$output .= '<div '. $this->get_render_attribute_string( 'carousel-setting' ) .' >';
													$output .= '</div>';
					$output .= '</div>';
				$output .= '</div>';

				$output .= $image_html;
				 
					echo '<a ' . $this->get_render_attribute_string( 'button-attr' ) .'>';	
					if ($settings['select-media'] == 'text') {
					echo  '<div class="video_cat"><p class="video-text btn btn-primary">' . html_entity_decode($settings['text']) . '</p></div>';
					} else {
					echo '<div class="icon">' . sprintf('<i aria-hidden="true" class="%1$s"></i>', esc_attr($settings['video-icon']['value'])) . '</div>';
									 } 
					echo '</a>';

							}

		$output .= '</div>';

		echo $output; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
	}
}
Plugin::instance()->widgets_manager->register_widget_type( new \Elementor\Widget_Video_Popup() );