<?php
/**
 * Logo Options
 *
 * @package karigari
 * @subpackage Core
 * @since karigari 1.0
 * @version 1.0
 */

Redux::setSection(
	'karigari_options',
	array(
		'title'  => esc_html__( 'Site Logo', 'karigari' ),
		'id'     => 'logo-opt',
		'icon'   => 'el el-flag',
		'desc'   => esc_html__( 'This section contains options for Logo.', 'karigari' ),
		'fields' => array(

			array(
				'id'       => 'opt-logo',
				'type'     => 'switch',
				'title'    => esc_html__( 'Logo Style', 'karigari' ),
				// Must provide key => value pairs for radio options.
				'on' => 'Logo Image',
				'off' => 'Logo Text',
				'default'  => '1',
			),

			// array(
			// 	'id'          => 'first-color',
			// 	'type'        => 'color',
			// 	'title'       => esc_html__( 'First Gradient Background', 'karigari' ),
			// 	'default'     => '#ff7225',
			// 	'transparent' => false,
			// ),

			// array(
			// 	'id'          => 'second-color',
			// 	'type'        => 'color',
			// 	'title'       => esc_html__( 'Second Gradient Background', 'karigari' ),
			// 	'default'     => '#ff5a00',
			// 	'transparent' => false,
			// ),

			array(
				'id'        => 'site-logo',
				'type'      => 'media',
				'url'       => false,
				'title'     => esc_html__( 'Dark Version Logo [ header 01 ]', 'karigari' ),
				'required' => array('opt-logo','equals', 1 ),
				'read-only' => false,
				'default'   => array( 'url' => plugin_dir_url( __DIR__ ) . '/assets/images/logo.png' ),
				'subtitle'  => esc_html__( 'Upload logo image for your Website. Otherwise site title will be displayed in place of logo.', 'karigari' ),
			),
			
			array(
				'id'        => 'site-logo-02',
				'type'      => 'media',
				'url'       => false,
				'title'     => esc_html__( 'Dark Version Logo [ header 02 ]', 'karigari' ),
				'required' => array('opt-logo','equals', 1 ),
				'read-only' => false,
				'default'   => array( 'url' => plugin_dir_url( __DIR__ ) . '/assets/images/logo.png' ),
				'subtitle'  => esc_html__( 'Upload logo image for your Website. Otherwise site title will be displayed in place of logo.', 'karigari' ),
			),

			array(
				'id'        => 'light-site-logo',
				'type'      => 'media',
				'url'       => false,
				'title'     => esc_html__( 'Light Version Logo', 'karigari' ),
				'required' => array('opt-logo','equals', 1 ),
				'read-only' => false,
				'default'   => array( 'url' => plugin_dir_url( __DIR__ ) . '/assets/images/white-logo.png' ),
				'subtitle'  => esc_html__( 'Upload logo image for your Website. Otherwise site title will be displayed in place of logo. It work with dark mode only', 'karigari' ),
			),

			array(
				'id'             => 'logo-height',
				'type'           => 'dimensions',
				'units'          => array( 'em', 'px', '%' ),    // You can specify a unit value. Possible: px, em, %
				'units_extended' => 'true',  // Allow users to select any type of unit
				'title'          => esc_html__( 'Logo Size', 'karigari' ),
				'subtitle'     	=> esc_html__( 'Leave blank for auto', 'karigari' ),
				'required' 		=> array('opt-logo','equals', 1 ),
				'output'         => array( 'header .site-branding a img.logo' ),
				// 'width'          => false,
			),

			array(
				'id'       => 'text-logo',
				'type'     => 'text',
				'title'    => esc_html__( 'Logo Text', 'karigari' ),
				'required' => array('opt-logo','equals', 0 ),
				'subtitle' => esc_html__( 'Subtitle', 'karigari' ),
				'desc'     => esc_html__( 'Field Description', 'karigari' ),
				'default'  => 'karigari',
			),

			array(
				'id'          => 'logo-typography',
				'type'        => 'typography',
				'title'       => esc_html__( 'Typography h2.site-description', 'karigari' ),
				// 'compiler'      => true,  // Use if you want to hook in your own CSS compiler
				// 'google'      => false,
				// Disable google fonts. Won't work if you haven't defined your google api key
				'font-backup' => true,
				// Select a backup non-google font in addition to a google font
				// 'font-style'    => false, // Includes font-style and weight. Can use font-style or font-weight to declare
				'subsets'       => false, // Only appears if google is true and subsets not set to false
				// 'font-size'     => false,
				'line-height'   => false,
				// 'word-spacing'  => true,  // Defaults to false
				// 'letter-spacing'=> true,  // Defaults to false
				// 'color'         => false,
				// 'preview'       => false, // Disable the previewer.
				'all_styles'  => true,
				// Enable all Google Font style/weight variations to be added to the page.
				'output'      => array( 'h1', 'color' => '.logo a' ),
				'required' => array('opt-logo','equals', 0 ),
				// An array of CSS selectors to apply this font style to dynamically.
				'compiler'    => array( 'site-description-compiler' ),
				// An array of CSS selectors to apply this font style to dynamically.
				'units'       => 'px',
				// Defaults to px.
				'text-align' => false,
				'default'     => array(
					'color' => '#ff4a17',
				),
				'subtitle'    => esc_html__( 'Typography option with each property can be called individually.', 'karigari' ),
			),

			array(
				'id'      => 'site-fevicon',
				'type'    => 'media',
				'url'     => false,
				'title'   => esc_html__( 'Site Fevicon', 'karigari' ),
				'default' => array( 'url' => plugin_dir_url( __DIR__ ) . 'assets/images/favicon.png' ),
			),

		),
	)
);

